@@ -13,35 +13,17 @@ from functools import partial
 import wx
 import wx.lib.mixins.inspection
 import wx.lib.scrolledpanel as scrolled
-try:
-    from wx._core import PyDeadObjectError
-except:
-    PyDeadObjectError = Exception
+import wx.dataview as dv
 
-import wx.lib.colourselect  as csel
 import numpy as np
 import matplotlib
 
-HAS_PLOT = False
-try:
-    from wxmplot import PlotPanel
-    HAS_PLOT = True
-except ImportError:
-    HAS_PLOT = False
-
-HAS_DV = False
-try:
-    import wx.dataview as dv
-    HAS_DV = True
-except:
-    pass
-
+from wxmplot import PlotPanel
 from wxutils import (SimpleText, EditableListBox, Font, FloatCtrl,
                      pack, Popup, Button, get_icon, Check, MenuItem,
                      Choice, FileOpen, FileSave, fix_filename, HLine,
                      GridPanel, CEN, LEFT, RIGHT)
 
-
 import larch
 from larch.site_config import icondir
 from larch.wxlib import PeriodicTablePanel, LarchWxApp
@@ -382,16 +364,15 @@ class EpicsXRFDisplayFrame(XRFDisplayFrame):
         btnpanel = wx.Panel(pane, name='buttons')
         btnsizer = wx.GridBagSizer(1, 1)
         btns = {}
-        sx = 30
+        sx = 36
         sy = int(sx/2)
         for i in range(1, self.nmca+1):
-            b = Button(btnpanel, '%d' % i, size=(sx, sx),
+            b = Button(btnpanel, f'{i}', size=(sx, sx),
                        action=partial(self.onSelectDet, index=i))
-            b.SetFont(Font(10))
+            b.SetFont(Font(9))
             self.wids['det%i' % i] = b
             btns[i] = b
         dtype = self.det_type.lower().replace('-', '').replace(' ', '').replace('_', '')
-
         if dtype.startswith('sxd7') and self.nmca == 7:
             btnsizer.Add((sx, sy), (0, 0), (1, 2), wx.ALIGN_LEFT, 1)
             btnsizer.Add(btns[6],  (1, 0), (2, 2), wx.ALIGN_LEFT, 1)
