@@ -10,7 +10,6 @@ Exposed functions here are
    imshow: display a false-color map from array data on
            a configurable Image Display Frame.
 '''
-
 import time
 import os
 import sys
@@ -20,19 +19,16 @@ from wxmplot import PlotFrame, ImageFrame, StackedPlotFrame
 from wxmplot.interactive import get_wxapp
 
 import larch
+from ..utils import mkdir
 from ..xrf import isLarchMCAGroup
 from ..larchlib import ensuremod
 from ..site_config import user_larchdir
 
 from .xrfdisplay import XRFDisplayFrame
 
-mpl_dir = os.path.join(user_larchdir, 'matplotlib')
-os.environ['MPLCONFIGDIR'] = mpl_dir
-if not os.path.exists(mpl_dir):
-    try:
-        os.makedirs(mpl_dir)
-    except:
-        pass
+mplconfdir = os.path.join(user_larchdir, 'matplotlib')
+mkdir(mplconfdir)
+os.environ['MPLCONFIGDIR'] = mplconfdir
 
 from matplotlib.axes import Axes
 HIST_DOC = Axes.hist.__doc__
@@ -41,7 +37,7 @@ IMG_DISPLAYS = {}
 PLOT_DISPLAYS = {}
 FITPLOT_DISPLAYS = {}
 XRF_DISPLAYS = {}
-
+DISPLAY_LIMITS = None
 PLOTOPTS = {'theme': 'light',
             'height': 550,
             'width': 600,
@@ -275,6 +271,17 @@ def get_display(win=1, _larch=None, wxparent=None, size=None,
         except:
             pass
 
+        global DISPLAY_LIMITS
+        if DISPLAY_LIMITS is None:
+            displays = [wx.Display(i) for i in range(wx.Display.GetCount())]
+            geoms = [d.GetGeometry() for d in displays]
+            _left = min([g.Left for g in geoms])
+            _right = max([g.Right for g in geoms])
+            _top = min([g.Top for g in geoms])
+            _bot = max([g.Bottom for g in geoms])
+            DISPLAY_LIMITS = [_left, _right, _top, _bot]
+
+
     win = max(1, min(MAX_WINDOWS, int(abs(win))))
     title   = 'Plot Window %i' % win
     symname = '%s.plot%i' % (_larch_name, win)
@@ -333,8 +340,23 @@ def get_display(win=1, _larch=None, wxparent=None, size=None,
             if parent is not None:
                 xpos, ypos = parent.GetPosition()
                 xsiz, ysiz = parent.GetSize()
-                display.SetPosition((xpos+(xsiz//4)*win, ypos+(ysiz//8)*win))
-
+                x = xpos + xsiz*0.75
+                y = ypos + ysiz*0.75
+                dlims = DISPLAY_LIMITS
+                if len(PLOT_DISPLAYS) > 0:
+                    try:
+                        xpos, ypos = PLOT_DISPLAYS[1].GetPosition()
+                        xsiz, ysiz = PLOT_DISPLAYS[1].GetSize()
+                    except:
+                        pass
+                off = 0.20*(win-1)
+                x = max(20, xpos + xsiz*off)
+                y = max(20, ypos + ysiz*off)
+                if y+0.75*ysiz > dlims[3]:
+                    y = 40+max(40, 40+ysiz*(off-0.5))
+                if x+0.75*xsiz > dlims[1]:
+                    x = 20+max(10, 10+xpos+xsiz*(off-0.5))
+                display.SetPosition((int(x), int(y)))
         ddict[win] = display
         return display, new_display
 
@@ -921,7 +943,10 @@ def _closeDisplays(_larch=None, **kws):
     for display in (PLOT_DISPLAYS, IMG_DISPLAYS,
                     FITPLOT_DISPLAYS, XRF_DISPLAYS):
         for win in display.values():
-            win.Destroy()
+            try:
+                win.Destroy()
+            except:
+                pass
 
 def get_zoomlimits(plotpanel, dgroup):
     """save current zoom limits, to be reapplied with set_zoomlimits()"""
