@@ -30,10 +30,10 @@ from larch import Group, site_config
 from larch.math import index_of
 from larch.fitting import group2params, param
 from larch.utils.jsonutils import encode4js, decode4js
-from larch.utils import fix_varname, fix_filename, gformat
+from larch.utils import fix_varname, fix_filename, gformat, mkdir
 from larch.io.export_modelresult import export_modelresult
 from larch.xafs import feffit_report, feffpath
-
+from larch.xafs.feffdat import FEFFDAT_VALUES
 from larch.xafs.xafsutils import FT_WINDOWS
 
 from larch.wxlib import (ReportFrame, BitmapButton, FloatCtrl, FloatSpin,
@@ -93,7 +93,7 @@ xftr({groupname:s}, rmin={rmin:.3f}, rmax={rmax:.3f}, dr={dr:.3f}, window='{rwin
 """
 
 COMMANDS['feffit_params_init'] = """# create feffit Parameter Group to hold fit parameters
-_feffit_params = param_group()
+_feffit_params = param_group(reff=-1.0)
 """
 
 COMMANDS['feffit_trans'] = """# define Fourier transform and fitting space
@@ -772,25 +772,29 @@ class FeffitPanel(TaskPanel):
         fit_rmin = self.add_floatspin('fit_rmin',  value=1, **fsopts)
         fit_rmax = self.add_floatspin('fit_rmax',  value=5, **fsopts)
 
-        wids['fit_kwstring'] = Choice(pan, size=(125, -1),
+        wids['fit_kwstring'] = Choice(pan, size=(150, -1),
                                      choices=list(Feffit_KWChoices.keys()))
         wids['fit_kwstring'].SetSelection(1)
 
-        wids['fit_kwindow'] = Choice(pan, choices=list(FT_WINDOWS), size=(125, -1))
+        wids['fit_kwindow'] = Choice(pan, choices=list(FT_WINDOWS), size=(150, -1))
 
         wids['fit_space'] = Choice(pan, choices=list(Feffit_SpaceChoices.keys()),
-                                   size=(125, -1))
+                                   size=(150, -1))
 
         wids['plotone_op'] = Choice(pan, choices=list(PlotOne_Choices.keys()),
-                                    action=self.onPlot, size=(125, -1))
+                                    action=self.onPlot, size=(150, -1))
         wids['plotone_op'].SetSelection(1)
         wids['plotalt_op'] = Choice(pan, choices=list(PlotAlt_Choices.keys()),
-                                    action=self.onPlot, size=(125, -1))
+                                    action=self.onPlot, size=(150, -1))
 
         wids['plot_win'] = Choice(pan, choices=PlotWindowChoices,
                                   action=self.onPlot, size=(60, -1))
         wids['plot_win'].SetStringSelection('2')
 
+        wids['plot_voffset'] =  FloatSpin(pan, value=0, digits=2, increment=0.25,
+                                          size=(100, -1), action=self.onPlot)
+
+
         ppanel = wx.Panel(pan)
         ppanel.SetMinSize((450, 20))
 
@@ -799,21 +803,18 @@ class FeffitPanel(TaskPanel):
         wids['plot_ftwindows'] = Check(ppanel, default=False, label='Plot FT Windows',
                                        action=self.onPlot)
 
-        wids['plot_voffset'] =  FloatSpin(ppanel, value=0, digits=2, increment=0.25,
-                                          size=(100, -1), action=self.onPlot)
-
         psizer = wx.BoxSizer(wx.HORIZONTAL)
         psizer.Add(wids['plot_paths'],  0, LEFT, 2)
         psizer.Add(wids['plot_ftwindows'], 0, LEFT, 2)
-        psizer.Add(SimpleText(ppanel, '  Offset ', size=(100, -1) ), 0, LEFT, 2)
-        psizer.Add(wids['plot_voffset'], 0, LEFT, 2)
+        #psizer.Add(SimpleText(ppanel, '  Offset ', size=(100, -1) ), 0, LEFT, 2)
+        #psizer.Add(wids['plot_voffset'], 0, LEFT, 2)
         pack(ppanel, psizer)
         wids['plot_current']  = Button(pan,'Plot Current Model',
-                                     action=self.onPlot,  size=(150, -1))
+                                     action=self.onPlot,  size=(175, -1))
         wids['do_fit']        = Button(pan, 'Fit Data to Model',
-                                      action=self.onFitModel,  size=(150, -1))
+                                      action=self.onFitModel,  size=(175, -1))
         wids['show_results']  = Button(pan, 'Show Fit Results',
-                                      action=self.onShowResults,  size=(150, -1))
+                                      action=self.onShowResults,  size=(175, -1))
         wids['show_results'].Disable()
 
 #         wids['do_fit_sel']= Button(pan, 'Fit Selected Groups',
@@ -853,8 +854,11 @@ class FeffitPanel(TaskPanel):
         pan.Add(wids['plot_current'], dcol=1, newrow=True)
         pan.Add(wids['plotone_op'], dcol=1)
         pan.Add(ppanel, dcol=4)
-        # pan.Add(wids['plot_ftwindows'], dcol=2)
-        add_text('Add Second Plot: ', newrow=True)
+        add_text('  ', dcol=2, newrow=True)
+        add_text('Vertical Offset' , newrow=False)
+        pan.Add(wids['plot_voffset'])
+
+        add_text('Second Plot: ', newrow=True)
         pan.Add(wids['plotalt_op'], dcol=1)
         add_text('Plot Window: ', newrow=False)
         pan.Add(wids['plot_win'], dcol=1)
@@ -1311,7 +1315,7 @@ class FeffitPanel(TaskPanel):
             for node in ast.walk(ast.parse(expr)):
                 if isinstance(node, ast.Name):
                     sym = node.id
-                    if sym not in symtable:
+                    if sym not in symtable and sym not in FEFFDAT_VALUES:
                         s = f"_feffit_params.{sym:s} = param({value:.4f}, name='{sym:s}', vary=True{extras:s})"
                         self.larch_eval(s)
             result = True
@@ -1538,16 +1542,7 @@ class FeffitPanel(TaskPanel):
 
     def autosave_script(self, text, fname='feffit_script.lar'):
         """autosave model result to user larch folder"""
-        confdir = os.path.join(site_config.user_larchdir, 'xas_viewer')
-        if not os.path.exists(confdir):
-            try:
-                os.makedirs(confdir)
-            except OSError:
-                title = "Cannot create XAS Viewer folder"
-                message = [f"Cannot create directory {confdir}"]
-                ExceptionPopup(self, title, message)
-                return
-
+        confdir = self.controller.larix_folder
         if fname is None:
             fname = 'feffit_script.lar'
         fullname = os.path.join(confdir, fname)
