@@ -17,7 +17,7 @@ from lmfit import Parameter
 import lmfit.models as lm_models
 
 from larch import Group, site_config
-from larch.utils import uname, gformat
+from larch.utils import uname, gformat, mkdir
 from larch.math import index_of
 from larch.io.export_modelresult import export_modelresult
 from larch.io import save_groups, read_groups
@@ -719,17 +719,20 @@ class PrePeakPanel(TaskPanel):
 
         self.wids = {}
 
-        fsopts = dict(digits=2, increment=0.1, with_pin=True)
-        # ppeak_e0   = self.add_floatspin('ppeak_e0', value=0, **fsopts)
+        fsopts = dict(digits=2, increment=0.1, min_val=-9999,
+                      max_val=9999, size=(125, -1), with_pin=True)
+
         ppeak_elo  = self.add_floatspin('ppeak_elo',  value=-13, **fsopts)
         ppeak_ehi  = self.add_floatspin('ppeak_ehi',  value=-3, **fsopts)
         ppeak_emin = self.add_floatspin('ppeak_emin', value=-20, **fsopts)
         ppeak_emax = self.add_floatspin('ppeak_emax', value=0, **fsopts)
 
+        self.loadresults_btn = Button(pan, 'Load Fit Result',
+                                      action=self.onLoadFitResult, size=(150, -1))
         self.showresults_btn = Button(pan, 'Show Fit Results',
                                       action=self.onShowResults, size=(150, -1))
         self.showresults_btn.Disable()
-
+        
         self.fitbline_btn  = Button(pan,'Fit Baseline', action=self.onFitBaseline,
                                     size=(150, -1))
 
@@ -744,19 +747,19 @@ class PrePeakPanel(TaskPanel):
         self.fitselected_btn.Disable()
         self.fitmodel_btn.Disable()
 
-        self.array_choice = Choice(pan, size=(175, -1),
+        self.array_choice = Choice(pan, size=(200, -1),
                                    choices=list(PrePeak_ArrayChoices.keys()))
         self.array_choice.SetSelection(0)
 
-        self.bline_choice = Choice(pan, size=(175, -1),
+        self.bline_choice = Choice(pan, size=(200, -1),
                                    choices=BaselineFuncs)
         self.bline_choice.SetSelection(2)
 
-        models_peaks = Choice(pan, size=(150, -1),
+        models_peaks = Choice(pan, size=(200, -1),
                               choices=ModelChoices['peaks'],
                               action=self.addModel)
 
-        models_other = Choice(pan, size=(150, -1),
+        models_other = Choice(pan, size=(200, -1),
                               choices=ModelChoices['other'],
                               action=self.addModel)
 
@@ -777,7 +780,8 @@ class PrePeakPanel(TaskPanel):
             pan.Add(SimpleText(pan, text), dcol=dcol, newrow=newrow)
 
         pan.Add(SimpleText(pan, 'Pre-edge Peak Fitting',
-                           size=(350, -1), **self.titleopts), style=LEFT, dcol=4)
+                           size=(350, -1), **self.titleopts), style=LEFT, dcol=5)
+        pan.Add(self.loadresults_btn)
 
         add_text('Array to fit: ')
         pan.Add(self.array_choice, dcol=3)
@@ -862,7 +866,6 @@ class PrePeakPanel(TaskPanel):
         if isinstance(dat, Group):
             if not hasattr(dat, 'norm'):
                 self.xasmain.process_normalization(dat)
-            # self.wids['ppeak_e0'].SetValue(dat.e0)
             if hasattr(dat, 'prepeaks'):
                 self.wids['ppeak_emin'].SetValue(dat.prepeaks.emin)
                 self.wids['ppeak_emax'].SetValue(dat.prepeaks.emax)
@@ -955,6 +958,7 @@ elo={elo:.3f}, ehi={ehi:.3f}, emin={emin:.3f}, emax={emax:.3f})"""
         self.fitselected_btn.Enable()
 
         i1, i2 = self.get_xranges(dgroup.energy)
+
         dgroup.yfit = dgroup.xfit = 0.0*dgroup.energy[i1:i2]
 
         self.onPlot(baseline_only=True)
@@ -1549,15 +1553,7 @@ write_ascii('{savefile:s}', {gname:s}.energy, {gname:s}.norm, {gname:s}.prepeaks
 
     def autosave_modelresult(self, result, fname=None):
         """autosave model result to user larch folder"""
-        confdir = os.path.join(site_config.user_larchdir, 'xas_viewer')
-        if not os.path.exists(confdir):
-            try:
-                os.makedirs(confdir)
-            except:
-                title = "Cannot create XAS Viewer folder"
-                message = [f"Cannot create directory {confdir}"]
-                ExceptionPopup(self, title, message)
-                return
+        confdir = self.controller.larix_folder
         if fname is None:
             fname = 'autosave_peakfile.modl'
         save_groups(os.path.join(confdir, fname), ['#peakfit 1.0', result])
