@@ -24,23 +24,12 @@ from larch.wxlib import (GridPanel, BitmapButton, FloatCtrl, FloatSpin,
                          get_zoomlimits, set_zoomlimits)
 
 from larch.xafs import etok, ktoe, find_energy_step
-from larch.utils.physical_constants import PI, DEG2RAD, PLANCK_HC
+from larch.utils.physical_constants import PI, DEG2RAD, PLANCK_HC, ATOM_SYMS
 from larch.math import smooth
 
 Plot_Choices = {'Normalized': 'norm', 'Derivative': 'dmude'}
 
 
-ELEM_LIST = ('H', 'He', 'Li', 'Be', 'B', 'C', 'N', 'O', 'F', 'Ne', 'Na',
-             'Mg', 'Al', 'Si', 'P', 'S', 'Cl', 'Ar', 'K', 'Ca', 'Sc', 'Ti',
-             'V', 'Cr', 'Mn', 'Fe', 'Co', 'Ni', 'Cu', 'Zn', 'Ga', 'Ge',
-             'As', 'Se', 'Br', 'Kr', 'Rb', 'Sr', 'Y', 'Zr', 'Nb', 'Mo',
-             'Tc', 'Ru', 'Rh', 'Pd', 'Ag', 'Cd', 'In', 'Sn', 'Sb', 'Te',
-             'I', 'Xe', 'Cs', 'Ba', 'La', 'Ce', 'Pr', 'Nd', 'Pm', 'Sm',
-             'Eu', 'Gd', 'Tb', 'Dy', 'Ho', 'Er', 'Tm', 'Yb', 'Lu', 'Hf',
-             'Ta', 'W', 'Re', 'Os', 'Ir', 'Pt', 'Au', 'Hg', 'Tl', 'Pb',
-             'Bi', 'Po', 'At', 'Rn', 'Fr', 'Ra', 'Ac', 'Th', 'Pa', 'U',
-             'Np', 'Pu', 'Am', 'Cm', 'Bk', 'Cf')
-
 EDGE_LIST = ('K', 'L3', 'L2', 'L1', 'M5', 'M4', 'M3')
 
 NORM_MU = 'Normalized \u03BC(E)'
@@ -87,6 +76,18 @@ def add_floatspin(name, value, panel, with_pin=True, xasmain=None,
     return fspin, pinb
 
 
+def get_view_limits(ppanel):
+    "get last zoom limits for a plot panel"
+    xlim = ppanel.axes.get_xlim()
+    ylim = ppanel.axes.get_ylim()
+    return (xlim, ylim)
+
+def set_view_limits(ppanel, xlim, ylim):
+    "set zoom limits for a plot panel, as found from get_view_limits"
+    ppanel.axes.set_xlim(xlim, emit=True)
+    ppanel.axes.set_ylim(ylim, emit=True)
+
+
 class OverAbsorptionDialog(wx.Dialog):
     """dialog for correcting over-absorption"""
     def __init__(self, parent, controller, **kws):
@@ -115,7 +116,7 @@ class OverAbsorptionDialog(wx.Dialog):
         wids['phi_in']  = FloatSpin(panel, **fs_opts)
         wids['phi_out'] = FloatSpin(panel, **fs_opts)
 
-        wids['elem'] = Choice(panel, choices=ELEM_LIST, size=(50, -1))
+        wids['elem'] = Choice(panel, choices=ATOM_SYMS[:98], size=(50, -1))
         wids['edge'] = Choice(panel, choices=EDGE_LIST, size=(50, -1))
 
         wids['formula'] = wx.TextCtrl(panel, -1, '', size=(250, -1))
@@ -166,6 +167,7 @@ class OverAbsorptionDialog(wx.Dialog):
                   newrow=True)
         panel.pack()
         fit_dialog_window(self, panel)
+        self.plot_results(keep_limits=False)
 
 
     def onDone(self, event=None):
@@ -226,11 +228,11 @@ class OverAbsorptionDialog(wx.Dialog):
         ngroup.journal.add('source_desc', f"fluo_corrected({olddesc})")
         ngroup.journal.add('fluor_correction_command', self.cmd)
 
-    def plot_results(self, event=None):
+    def plot_results(self, event=None, keep_limits=True):
         ppanel = self.controller.get_display(stacked=False).panel
-        ppanel.oplot
+
         dgroup = self.dgroup
-        zoom_limits = get_zoomlimits(ppanel, dgroup)
+        xlim, ylim = get_view_limits(ppanel)
         path, fname = os.path.split(dgroup.filename)
 
         opts = dict(linewidth=3, ylabel=plotlabels.norm,
@@ -241,13 +243,17 @@ class OverAbsorptionDialog(wx.Dialog):
             opts['xmin'] = dgroup.e0 + self.controller.plot_erange[0]
             opts['xmax'] = dgroup.e0 + self.controller.plot_erange[1]
 
+        if not hasattr(dgroup, 'norm_corr'):
+            dgroup.norm_corr = dgroup.norm[:]
+
         ppanel.plot(dgroup.energy, dgroup.norm_corr, zorder=10, marker=None,
                     title='Over-absorption Correction:\n %s' % fname,
                     label='corrected', **opts)
 
         ppanel.oplot(dgroup.energy, dgroup.norm, zorder=10, marker='o',
                      markersize=3, label='original', **opts)
-        set_zoomlimits(ppanel, zoom_limits) or ppanel.unzoom_all()
+        if keep_limits:
+            set_view_limits(ppanel, xlim, ylim)
         ppanel.canvas.draw()
         ppanel.conf.draw_legend(show=True)
 
@@ -346,7 +352,7 @@ class EnergyCalibrateDialog(wx.Dialog):
 
         fit_dialog_window(self, panel)
 
-        self.plot_results()
+        self.plot_results(keep_limits=False)
         wx.CallAfter(self.get_groups_shared_energyrefs)
 
     def on_select(self, event=None, opt=None):
@@ -364,6 +370,8 @@ class EnergyCalibrateDialog(wx.Dialog):
             eref = None
         if eref is None:
             eref = dgroup.groupname
+
+
         for key, val in self.controller.file_groups.items():
             if dgroup.groupname == val:
                 continue
@@ -372,7 +380,8 @@ class EnergyCalibrateDialog(wx.Dialog):
                 geref = g.config.xasnorm.get('energy_ref', None)
             except:
                 geref = None
-            if geref == eref:
+            # print(key, val, geref, geref == ref_filename)
+            if geref == eref or geref == dgroup.filename:
                 sharedrefs.append(key)
         self.wids['sharedref_msg'].SetLabel(f" {len(sharedrefs):d} groups share this energy reference")
         return sharedrefs
@@ -405,7 +414,7 @@ class EnergyCalibrateDialog(wx.Dialog):
             newx = dat.xdat + pars['eshift'].value
             scale = pars['scale'].value
             y = interp(newx, dat.dmude, ref.xdat, kind='cubic')
-            return smooth(newx, y*scale-ref.dmude, xstep=estep, sigma=0.50)[i1:i2]
+            return smooth(ref.xdat, y*scale-ref.dmude, xstep=estep, sigma=0.50)[i1:i2]
 
         params = Parameters()
         params.add('eshift', value=ref.e0-dat.e0, min=-50, max=50)
@@ -476,12 +485,13 @@ class EnergyCalibrateDialog(wx.Dialog):
         ngroup.journal.add('source_desc', f"energy_shifted({olddesc}, {eshift:.4f})")
         ngroup.journal.add('energy_shift ', 0.0)
 
-    def plot_results(self, event=None):
+    def plot_results(self, event=None, keep_limits=True):
         ppanel = self.controller.get_display(stacked=False).panel
         ppanel.oplot
         xnew, ynew = self.data
         dgroup = self.dgroup
-        zoom_limits = get_zoomlimits(ppanel, dgroup)
+
+        xlim, ylim = get_view_limits(ppanel)
         path, fname = os.path.split(dgroup.filename)
 
         wids = self.wids
@@ -499,7 +509,7 @@ class EnergyCalibrateDialog(wx.Dialog):
             ynew = np.gradient(ynew)/np.gradient(xnew)
             ylabel = plotlabels.dmude
 
-        opts = dict(xmin=xmin, xmax=xmax, ylabel=ylabel,
+        opts = dict(xmin=xmin, xmax=xmax, ylabel=ylabel, delay_draw=True,
                     xlabel=plotlabels.energy, show_legend=True)
 
         if self.controller.plot_erange is not None:
@@ -512,11 +522,10 @@ class EnergyCalibrateDialog(wx.Dialog):
 
         ppanel.plot(xold, yold, zorder=10, marker='o', markersize=3,
                      label='original', linewidth=2, color='#1f77b4',
-                     title=f'Energy Calibration:\n {fname}',
-                     delay_draw=True, **opts)
+                     title=f'Energy Calibration:\n {fname}', **opts)
 
         ppanel.oplot(xnew, ynew, zorder=15, marker='+', markersize=3,
-                    linewidth=2, label='shifted', delay_draw=True,
+                    linewidth=2, label='shifted',
                     color='#d62728', **opts)
 
         if wids['reflist'].GetStringSelection() != 'None':
@@ -527,12 +536,11 @@ class EnergyCalibrateDialog(wx.Dialog):
 
             ppanel.oplot(xref, yref, style='solid', zorder=5, color='#2ca02c',
                          marker=None, label=refgroup.filename, **opts)
-
-        set_zoomlimits(ppanel, zoom_limits) or ppanel.unzoom_all()
+        if keep_limits:
+            set_view_limits(ppanel, xlim, ylim)
         ppanel.canvas.draw()
 
 
-
     def GetResponse(self):
         raise AttributeError("use as non-modal dialog!")
 
@@ -548,7 +556,7 @@ class RebinDataDialog(wx.Dialog):
         xmin = min(self.dgroup.energy)
         xmax = max(self.dgroup.energy)
         e0val = getattr(self.dgroup, 'e0', xmin)
-        xanes_step = 0.05 * max(1, int(e0val / 1250.0))  # E0/25000, round down to 0.05
+        xanes_step = 0.05 * (1 + max(1, int(e0val / 2000.0)))
         self.data = [self.dgroup.energy[:], self.dgroup.mu[:],
                      self.dgroup.mu*0, e0val]
 
@@ -638,12 +646,11 @@ class RebinDataDialog(wx.Dialog):
         fit_dialog_window(self, panel)
 
         self.on_rebin()
-        self.plot_results()
+        self.plot_results(keep_limits=False)
 
     def onDone(self, event=None):
         self.Destroy()
 
-
     def on_groupchoice(self, event=None):
         self.dgroup = self.controller.get_group(self.wids['grouplist'].GetStringSelection())
         self.wids['save_as_name'].SetValue(self.dgroup.filename + '_rebin')
@@ -719,28 +726,29 @@ class RebinDataDialog(wx.Dialog):
     def on_done(self, event=None):
         self.Destroy()
 
-    def plot_results(self):
+    def plot_results(self, event=None, keep_limits=True):
         ppanel = self.controller.get_display(stacked=False).panel
         xnew, ynew, yerr, e0 = self.data
         dgroup = self.dgroup
-        zoom_limits = get_zoomlimits(ppanel, dgroup)
+        xlim, ylim = get_view_limits(ppanel)
         path, fname = os.path.split(dgroup.filename)
 
-        opts = {}
+        opts = {'delay_draw': True}
         if self.controller.plot_erange is not None:
             opts['xmin'] = dgroup.e0 + self.controller.plot_erange[0]
             opts['xmax'] = dgroup.e0 + self.controller.plot_erange[1]
 
-        ppanel.plot(xnew, ynew, zorder=20, delay_draw=True, marker='square',
+        ppanel.plot(xnew, ynew, zorder=20, marker='square',
                     linewidth=3, title='Enegy rebinning:\n %s' % fname,
                     label='rebinned', xlabel=plotlabels.energy,
                     ylabel=plotlabels.mu, **opts)
 
         xold, yold = self.dgroup.energy, self.dgroup.mu
-        ppanel.oplot(xold, yold, zorder=10, delay_draw=False,
+        ppanel.oplot(xold, yold, zorder=10, 
                      marker='o', markersize=4, linewidth=2.0,
                      label='original', show_legend=True, **opts)
-        set_zoomlimits(ppanel, zoom_limits) or ppanel.unzoom_all()
+        if keep_limits:
+            set_view_limits(ppanel, xlim, ylim)
         ppanel.canvas.draw()
 
     def GetResponse(self):
@@ -784,18 +792,20 @@ class SmoothDataDialog(wx.Dialog):
 
         opts  = dict(size=(50, -1), act_on_losefocus=True, odd_only=False)
 
-        self.sigma = FloatCtrl(panel, value=1, precision=2, minval=0, **opts)
-        self.par_n = FloatCtrl(panel, value=2, precision=0, minval=1, **opts)
-        self.par_o = FloatCtrl(panel, value=1, precision=0, minval=1, **opts)
+        self.sigma = FloatSpin(panel, value=1, digits=2, min_val=0, increment=0.1,
+                               size=(60, -1), action=self.on_smooth)
 
-        for fc in (self.sigma, self.par_n, self.par_o):
-            fc.SetAction(self.on_smooth)
+        self.par_n = FloatSpin(panel, value=2, digits=0, min_val=1, increment=1,
+                               size=(60, -1), action=self.on_smooth)
+
+        self.par_o = FloatSpin(panel, value=1, digits=0, min_val=1, increment=1,
+                               size=(60, -1), action=self.on_smooth)
+
+        # for fc in (self.sigma, self.par_n, self.par_o):
+        # self.sigma.SetAction(self.on_smooth)
 
         self.message = SimpleText(panel, label='         ', size=(200, -1))
 
-        # wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
-        #                       action=self.on_apply)
-        # SetTip(wids['apply'], 'Save corrected data, overwrite current arrays')
 
         wids['save_as'] = Button(panel, 'Save As New Group: ', size=(150, -1),
                            action=self.on_saveas)
@@ -812,9 +822,9 @@ class SmoothDataDialog(wx.Dialog):
 
         add_text('Smoothing Method: ')
         panel.Add(self.smooth_op)
-        add_text(' n= ', newrow=False)
+        add_text(' n = ', newrow=False)
         panel.Add(self.par_n)
-        add_text(' order= ', newrow=False)
+        add_text(' order=  ', newrow=False)
         panel.Add(self.par_o)
 
         add_text('Convolution Form: ')
@@ -834,7 +844,7 @@ class SmoothDataDialog(wx.Dialog):
         panel.pack()
         fit_dialog_window(self, panel)
 
-        self.plot_results()
+        self.plot_results(keep_limits=False)
 
     def onDone(self, event=None):
         self.Destroy()
@@ -849,6 +859,8 @@ class SmoothDataDialog(wx.Dialog):
         smoothop = self.smooth_op.GetStringSelection().lower()
 
         convop   = self.conv_op.GetStringSelection()
+        self.conv_op.Enable(smoothop.startswith('conv'))
+        self.sigma.Enable(smoothop.startswith('conv'))
         self.message.SetLabel('')
         self.par_n.SetMin(1)
         self.par_n.odd_only = False
@@ -856,9 +868,11 @@ class SmoothDataDialog(wx.Dialog):
         par_o = int(self.par_o.GetValue())
         sigma = self.sigma.GetValue()
         cmd = '{group:s}.mu' # No smoothing
+        estep = find_energy_step(self.data[0])
         if smoothop.startswith('box'):
             self.par_n.Enable()
             cmd = "boxcar({group:s}.mu, {par_n:d})"
+            self.conv_op.Disable()
         elif smoothop.startswith('savi'):
             self.par_n.Enable()
             self.par_n.odd_only = True
@@ -875,7 +889,6 @@ class SmoothDataDialog(wx.Dialog):
             cmd = "savitzky_golay({group:s}.mu, {par_n:d}, {par_o:d})"
 
         elif smoothop.startswith('conv'):
-            estep = find_energy_step(self.data[0])
             cmd = "smooth({group:s}.energy, {group:s}.mu, xstep={estep:f}, sigma={sigma:f}, form='{convop:s}')"
         self.cmd = cmd.format(group=self.dgroup.groupname, convop=convop,
                               estep=estep, sigma=sigma, par_n=par_n, par_o=par_o)
@@ -914,28 +927,29 @@ class SmoothDataDialog(wx.Dialog):
     def on_done(self, event=None):
         self.Destroy()
 
-    def plot_results(self):
+    def plot_results(self, event=None, keep_limits=True):
         ppanel = self.controller.get_display(stacked=False).panel
         xnew, ynew = self.data
         dgroup = self.dgroup
-        zoom_limits = get_zoomlimits(ppanel, dgroup)
         path, fname = os.path.split(dgroup.filename)
+        opts = {'delay_draw': True}
+        xlim, ylim = get_view_limits(ppanel)
 
-        opts = {}
         if self.controller.plot_erange is not None:
             opts['xmin'] = dgroup.e0 + self.controller.plot_erange[0]
             opts['xmax'] = dgroup.e0 + self.controller.plot_erange[1]
 
-        ppanel.plot(xnew, ynew, zorder=20, delay_draw=True, marker=None,
+        ppanel.plot(xnew, ynew, zorder=20, marker=None,
                     linewidth=3, title='Smoothing:\n %s' % fname,
                     label='smoothed', xlabel=plotlabels.energy,
                     ylabel=plotlabels.mu, **opts)
 
         xold, yold = self.dgroup.energy, self.dgroup.mu
-        ppanel.oplot(xold, yold, zorder=10, delay_draw=False,
+        ppanel.oplot(xold, yold, zorder=10, 
                      marker='o', markersize=4, linewidth=2.0,
                      label='original', show_legend=True, **opts)
-        set_zoomlimits(ppanel, zoom_limits) or ppanel.unzoom_all()
+        if keep_limits:
+            set_view_limits(ppanel, xlim, ylim)
         ppanel.canvas.draw()
 
     def GetResponse(self):
@@ -1004,7 +1018,7 @@ class DeconvolutionDialog(wx.Dialog):
         panel.pack()
 
         fit_dialog_window(self, panel)
-        self.plot_results()
+        self.plot_results(keep_limits=False)
 
     def onDone(self, event=None):
         self.Destroy()
@@ -1055,28 +1069,29 @@ class DeconvolutionDialog(wx.Dialog):
         self.parent.process_normalization(dgroup)
         self.plot_results()
 
-    def plot_results(self):
+    def plot_results(self, event=None, keep_limits=True):
         ppanel = self.controller.get_display(stacked=False).panel
         xnew, ynew = self.data
         dgroup = self.dgroup
-        zoom_limits = get_zoomlimits(ppanel, dgroup)
+        xlim, ylim = get_view_limits(ppanel)
         path, fname = os.path.split(dgroup.filename)
 
-        opts = {}
+        opts = {'delay_draw': True}
         if self.controller.plot_erange is not None:
             opts['xmin'] = dgroup.e0 + self.controller.plot_erange[0]
             opts['xmax'] = dgroup.e0 + self.controller.plot_erange[1]
 
-        ppanel.plot(xnew, ynew, zorder=20, delay_draw=True, marker=None,
+        ppanel.plot(xnew, ynew, zorder=20, marker=None,
                     linewidth=3, title='Deconvolving:\n %s' % fname,
                     label='deconvolved', xlabel=plotlabels.energy,
                     ylabel=plotlabels.mu, **opts)
 
         xold, yold = self.dgroup.energy, self.dgroup.norm
-        ppanel.oplot(xold, yold, zorder=10, delay_draw=False,
+        ppanel.oplot(xold, yold, zorder=10,
                      marker='o', markersize=4, linewidth=2.0,
                      label='original', show_legend=True, **opts)
-        set_zoomlimits(ppanel, zoom_limits) or ppanel.unzoom_all()
+        if keep_limits:
+            set_view_limits(ppanel, xlim, ylim)
         ppanel.canvas.draw()
 
     def GetResponse(self):
@@ -1194,7 +1209,7 @@ class DeglitchDialog(wx.Dialog):
         panel.pack()
 
         fit_dialog_window(self, panel)
-        self.plot_results(use_zoom=False)
+        self.plot_results(keep_limits=False)
 
     def onDone(self, event=None):
         self.Destroy()
@@ -1308,7 +1323,7 @@ class DeglitchDialog(wx.Dialog):
 
         self.parent.process_normalization(ngroup)
 
-    def plot_results(self, use_zoom=True):
+    def plot_results(self, event=None, keep_limits=True):
         ppanel = self.controller.get_display(stacked=False).panel
 
         xdat, ydat = self.data
@@ -1330,7 +1345,8 @@ class DeglitchDialog(wx.Dialog):
             xmin = self.dgroup.e0
             xlabel = xlabel=plotlabels.ewithk
 
-        opts = dict(xlabel=xlabel, title='De-glitching:\n %s' % fname)
+        opts = dict(xlabel=xlabel, title='De-glitching:\n %s' % fname,
+                    delay_draw=True)
 
         ylabel =  {'mu': plotlabels.mu,
                    'norm': plotlabels.norm,
@@ -1341,9 +1357,7 @@ class DeglitchDialog(wx.Dialog):
         dgroup.plot_xlabel = xlabel
         dgroup.plot_ylabel = ylabel
 
-        zoom_limits = None
-        if use_zoom:
-            zoom_limits = get_zoomlimits(ppanel, dgroup)
+        xlim, ylim = get_view_limits(ppanel)
 
         ppanel.plot(xdat, ydat, zorder=10, marker=None, linewidth=3,
                     label='original', ylabel=ylabel, **opts)
@@ -1359,9 +1373,11 @@ class DeglitchDialog(wx.Dialog):
             s = '' if ex < 0 else '\n[%.1f]' % (etok(ex))
             return r"%1.4g%s" % (x, s)
 
-        set_zoomlimits(ppanel, zoom_limits) or ppanel.unzoom_all()
+        if keep_limits:
+            set_view_limits(ppanel, xlim, ylim)
         if plottype in ('chie', 'chiew'):
             ppanel.axes.xaxis.set_major_formatter(FuncFormatter(ek_formatter))
+
         ppanel.canvas.draw()
 
         self.history_message.SetLabel('%i items in history' % (len(self.xmasks)-1))
