@@ -79,7 +79,7 @@ CEN |=  wx.ALL
 FILE_WILDCARDS = "Data Files|*.0*;*.dat;*.DAT;*.xdi;*.prj;*.sp*c;*.h*5;*.larix|All files (*.*)|*.*"
 
 ICON_FILE = 'onecone.ico'
-XASVIEW_SIZE = (1010, 810)
+XASVIEW_SIZE = (1020, 830)
 PLOTWIN_SIZE = (550, 550)
 
 NB_PANELS = {'Normalization': XASNormPanel,
@@ -93,6 +93,8 @@ NB_PANELS = {'Normalization': XASNormPanel,
 QUIT_MESSAGE = '''Really Quit? You may want to save your project before quitting.
  This is not done automatically!'''
 
+LARIX_TITLE = "Larix (was XAS Viewer): XAS Visualization and Analysis"
+
 
 def assign_gsescan_groups(group):
     labels = group.array_labels
@@ -119,7 +121,7 @@ class PreferencesFrame(wx.Frame):
     """ edit preferences"""
     def __init__(self, parent, controller, **kws):
         self.controller = controller
-        wx.Frame.__init__(self, None, -1,  'XAS_Viewer Preferences',
+        wx.Frame.__init__(self, None, -1,  'Larix Preferences',
                           style=FRAMESTYLE, size=(700, 725))
 
         sizer = wx.BoxSizer(wx.VERTICAL)
@@ -237,9 +239,9 @@ class PreferencesFrame(wx.Frame):
     def onSave(self, event=None):
         self.controller.save_config()
 
-class XASFrame(wx.Frame):
-    _about = """Larch XAS GUI: XAS Visualization and Analysis
 
+class XASFrame(wx.Frame):
+    _about = f"""{LARIX_TITLE}
     Matt Newville <newville @ cars.uchicago.edu>
     """
     def __init__(self, parent=None, _larch=None, filename=None,
@@ -259,7 +261,7 @@ class XASFrame(wx.Frame):
         self.last_athena_file = None
         self.paths2read = []
         self.current_filename = filename
-        title = "Larch XAS GUI: XAS Visualization and Analysis"
+        title = LARIX_TITLE
 
         self.larch_buffer = parent
         if not isinstance(parent, LarchFrame):
@@ -298,15 +300,15 @@ class XASFrame(wx.Frame):
         for i in range(len(statusbar_fields)):
             self.statusbar.SetStatusText(statusbar_fields[i], i)
         self.Show()
-        plotframe = self.controller.get_display(stacked=False)
-        xpos, ypos = self.GetPosition()
-        xsiz, ysiz = self.GetSize()
-        plotframe.SetPosition((xpos+xsiz+5, ypos))
 
         self.Raise()
         self.statusbar.SetStatusText('ready', 1)
         self.timers['autosave'].Start(30_000)
 
+        plotframe = self.controller.get_display(stacked=False)
+        xpos, ypos = self.GetPosition()
+        xsiz, ysiz = self.GetSize()
+        wx.CallAfter(plotframe.SetPosition, (xpos+xsiz+2, ypos))
         if self.current_filename is not None:
             wx.CallAfter(self.onRead, self.current_filename)
 
@@ -389,8 +391,8 @@ class XASFrame(wx.Frame):
         pack(panel, sizer)
         splitter.SplitVertically(leftpanel, panel, 1)
 
-    def process_normalization(self, dgroup, force=True):
-        self.get_nbpage('xasnorm')[1].process(dgroup, force=force)
+    def process_normalization(self, dgroup, force=True, use_form=True):
+        self.get_nbpage('xasnorm')[1].process(dgroup, force=force, use_form=use_form)
 
     def process_exafs(self, dgroup, force=True):
         self.get_nbpage('exafs')[1].process(dgroup, force=force)
@@ -443,7 +445,7 @@ class XASFrame(wx.Frame):
 
         if (getattr(dgroup, 'datatype', 'raw').startswith('xa') and not
             (hasattr(dgroup, 'norm') and hasattr(dgroup, 'e0'))):
-            self.process_normalization(dgroup, force=True)
+            self.process_normalization(dgroup, force=True, use_form=False)
 
         if filename is None:
             filename = dgroup.filename
@@ -481,7 +483,6 @@ class XASFrame(wx.Frame):
         group_menu = wx.Menu()
         data_menu = wx.Menu()
         feff_menu = wx.Menu()
-        ppeak_menu = wx.Menu()
         m = {}
 
         MenuItem(self, fmenu, "&Open Data File\tCtrl+O",
@@ -543,6 +544,9 @@ class XASFrame(wx.Frame):
                  'Show Larch Programming Buffer',
                  self.onShowLarchBuffer)
 
+#         MenuItem(self, fmenu, 'wxInspect\tCtrl+I',
+#                  'Show wx inspection window',   self.onwxInspect)
+
         MenuItem(self, fmenu, 'Edit Preferences\tCtrl+E', 'Customize Preferences',
                  self.onPreferences)
 
@@ -600,14 +604,10 @@ class XASFrame(wx.Frame):
         MenuItem(self, data_menu, "Add and Subtract Spectra",
                  "Calculations of Spectra",  self.onSpectraCalc)
 
-        MenuItem(self, ppeak_menu, "Load Pre-edge Peak Model",
-                 "Load saved model for Pre-edge Peak Fitting",
-                 self.onPrePeakLoad)
 
         self.menubar.Append(fmenu, "&File")
         self.menubar.Append(group_menu, "Groups")
         self.menubar.Append(data_menu, "Data")
-        self.menubar.Append(ppeak_menu, "Pre-edge Peaks")
 
         MenuItem(self, feff_menu, "Browse CIF Structures, Run Feff",
                  "Browse CIF Structure, run Feff", self.onCIFBrowse)
@@ -619,7 +619,7 @@ class XASFrame(wx.Frame):
         self.menubar.Append(feff_menu, "Feff")
 
         hmenu = wx.Menu()
-        MenuItem(self, hmenu, 'About XAS Viewer', 'About XAS Viewer',
+        MenuItem(self, hmenu, 'About Larix', 'About Larix',
                  self.onAbout)
         MenuItem(self, hmenu, 'Check for Updates', 'Check for Updates',
                  self.onCheckforUpdates)
@@ -628,6 +628,9 @@ class XASFrame(wx.Frame):
         self.SetMenuBar(self.menubar)
         self.Bind(wx.EVT_CLOSE,  self.onClose)
 
+    def onwxInspect(self, evt=None):
+        wx.GetApp().ShowInspectionTool()
+
     def onShowLarchBuffer(self, evt=None):
         if self.larch_buffer is None:
             self.larch_buffer = LarchFrame(_larch=self.larch, is_standalone=False)
@@ -638,7 +641,7 @@ class XASFrame(wx.Frame):
         wildcard = 'Larch file (*.lar)|*.lar|All files (*.*)|*.*'
         path = FileSave(self, message='Save Session History as Larch Script',
                         wildcard=wildcard,
-                        default_file='xas_viewer_history.lar')
+                        default_file='larix_history.lar')
         if path is not None:
             self.larch._larch.input.history.save(path, session_only=True)
             self.write_message("Wrote history %s" % path, 0)
@@ -681,7 +684,7 @@ class XASFrame(wx.Frame):
 
         try:
             groups2csv(savegroups, outfile, x=res.xarray, y=res.yarray,
-                    delim=res.delim, individual=res.individual, _larch=self.larch)
+                    delim=res.delim, individual=res.individual)
             self.write_message(f"Exported CSV file {outfile:s}")
         except:
             title = "Could not export CSV File"
@@ -749,7 +752,7 @@ class XASFrame(wx.Frame):
                                   "Overwrite existing file?", style=wx.YES_NO):
                 return
 
-        aprj = AthenaProject(filename=filename, _larch=self.larch)
+        aprj = AthenaProject(filename=filename)
         for label, grp in zip(grouplist, savegroups):
             aprj.add_group(grp)
         aprj.save(use_gzip=True)
@@ -830,7 +833,7 @@ class XASFrame(wx.Frame):
     def onClearSession(self, evt=None):
         conf = self.controller.get_config('autosave',
                                           {'fileroot': 'autosave'})
-        afile = os.path.join(user_larchdir, 'xas_viewer',
+        afile = os.path.join(self.controller.larix_folder,
                              conf['fileroot']+'.larix')
 
         msg = f"""Session will be saved to
@@ -1028,24 +1031,19 @@ before clearing"""
         if self.has_datagroup():
             DeconvolutionDialog(self, self.controller).Show()
 
-    def onPrePeakLoad(self, event=None):
-        idx, peakpage = self.get_nbpage('prepeak')
-        self.nb.SetSelection(idx)
-        peakpage.onLoadFitResult()
-
     def onConfigDataFitting(self, event=None):
         pass
 
     def onAbout(self, event=None):
         info = AboutDialogInfo()
-        info.SetName('XAS Viewer')
+        info.SetName('Larix')
         info.SetDescription('X-ray Absorption Visualization and Analysis')
         info.SetVersion('Larch %s ' % larch.version.__version__)
         info.AddDeveloper('Matthew Newville: newville at cars.uchicago.edu')
         dlg = AboutBox(info)
 
     def onCheckforUpdates(self, event=None):
-        dlg = LarchUpdaterDialog(self, caller='XAS Viewer')
+        dlg = LarchUpdaterDialog(self, caller='Larix')
         dlg.Raise()
         dlg.SetWindowStyle(wx.STAY_ON_TOP)
         res = dlg.GetResponse()
@@ -1118,7 +1116,8 @@ before clearing"""
 
     def onCIFBrowse(self, event=None):
         self.show_subframe('cif_feff', CIFFrame, _larch=self.larch,
-                           path_importer=self.get_nbpage('feffit')[1].add_path)
+                           path_importer=self.get_nbpage('feffit')[1].add_path,
+                           with_feff=True)
 
     def onStructureBrowse(self, event=None):
         self.show_subframe('structure_feff', Structure2FeffFrame, _larch=self.larch,
@@ -1708,13 +1707,12 @@ class XASViewer(LarchWxApp):
         self.SetTopWindow(frame)
         return True
 
-
-def xas_viewer(**kws):
+def larix(**kws):
     XASViewer(**kws)
 
 if __name__ == "__main__":
     import argparse
-    parser = argparse.ArgumentParser(description="Larch XAS GUI")
+    parser = argparse.ArgumentParser(description=LARIX_TITLE)
     parser.add_argument(
         '-f', '--filename',
         dest='filename',
