@@ -4,37 +4,37 @@ GUI for displaying 1D XRD images
 
 '''
 import os
-from os.path import expanduser
-
-import numpy as np
-from numpy.polynomial.chebyshev import chebfit
 import sys
 import time
-import re
-import math
 
-from threading import Thread
 from functools import partial
 
+import numpy as np
+from numpy.polynomial.chebyshev import chebfit, chebval
+
+from pyFAI.azimuthalIntegrator import AzimuthalIntegrator
 import pyFAI.units
+pyFAI.use_opencl = False
 
 import wx
 import wx.lib.scrolledpanel as scrolled
 from wxmplot import PlotPanel
 
+from lmfit.lineshapes import gaussian
+
 import larch
 from larch.larchlib import read_workdir, save_workdir
 from larch.utils import nativepath, get_cwd, gformat, fix_filename
 from larch.utils.physical_constants import PLANCK_HC
 from larch.xray import XrayBackground
-from larch.xrd import (cifDB, SearchCIFdb, QSTEP, QMIN, QMAX, CATEGORIES,
-                       match_database, d_from_q,twth_from_q,q_from_twth,
-                       d_from_twth,twth_from_d,q_from_d, lambda_from_E,
-                       E_from_lambda,calc_broadening,
-                       instrumental_fit_uvw,peaklocater,peakfitter,
-                       xrd1d, peakfinder_methods,SPACEGROUPS, create_xrdcif,
-                       save1D, read_poni)
+from larch.wxxas import RemoveDialog
+from larch.io import tifffile
 
+from larch.xrd import (d_from_q,twth_from_q,q_from_twth,
+                       d_from_twth,twth_from_d,q_from_d,
+                       lambda_from_E, E_from_lambda, calc_broadening,
+                       instrumental_fit_uvw,peaklocater,peakfitter,
+                       xrd1d, peakfinder_methods, save1D, read_poni)
 
 from larch.wxlib import (ReportFrame, BitmapButton, FloatCtrl, FloatSpin,
                          SetTip, GridPanel, get_icon, SimpleText, pack,
@@ -42,9 +42,14 @@ from larch.wxlib import (ReportFrame, BitmapButton, FloatCtrl, FloatSpin,
                          set_color, CEN, RIGHT, LEFT, FRAMESTYLE, Font,
                          FONTSIZE, FONTSIZE_FW, FileSave, FileOpen,
                          flatnotebook, Popup, FileCheckList,
-                         EditableListBox, ExceptionPopup)
+                         EditableListBox, ExceptionPopup, CIFFrame,
+                         LarchFrame, LarchWxApp)
+
+MAXVAL = 2**32 - 2**15
+MAXVAL_INT16 = 2**16 - 8
 
 XYWcards = "XY Data File(*.xy)|*.xy|All files (*.*)|*.*"
+TIFFWcards = "TIFF Files|*.tif;*.tiff|All files (*.*)|*.*"
 PlotWindowChoices = ['1', '2', '3', '4', '5', '6', '7', '8', '9']
 
 X_SCALES = [u'q (\u212B\u207B\u00B9)', u'2\u03B8 (\u00B0)', u'd (\u212B)']
@@ -58,10 +63,10 @@ PLOT_CHOICES = list(PLOT_TYPES.keys())
 PLOT_CHOICES_MULTI = [PLOT_CHOICES[0], PLOT_CHOICES[2]]
 
 SCALE_METHODS = {'Max Raw Intensity': 'raw_max',
-                 'Max Background-Subtracted Intensity': 'sub_max',                 
+                 'Max Background-Subtracted Intensity': 'sub_max',
                  'Max Background Intensity': 'bkg_max',
                  'Mean Raw Intensity': 'raw_mean',
-                 'Mean Background-Subtracted Intensity': 'sub_mean',                 
+                 'Mean Background-Subtracted Intensity': 'sub_mean',
                  'Mean Background Intensity': 'bkg_mean'}
 
 def keyof(dictlike, value, default):
@@ -76,7 +81,7 @@ def keyof(dictlike, value, default):
             return key
     return defout
 
-    
+
 def smooth_bruckner(y, smooth_points, iterations):
     y_original = y
     N_data = y.size
@@ -123,44 +128,151 @@ def extract_background(x, y, smooth_width=0.1, iterations=40, cheb_order=40):
     :return: vector of extracted y background
     """
     smooth_points = int((float(smooth_width) / (x[1] - x[0])))
-    # print('bkg ', smooth_points, iterations,cheb_order)
     y_smooth = smooth_bruckner(y, abs(smooth_points), iterations)
     # get cheb input parameters
     x_cheb = 2. * (x - x[0]) / (x[-1] - x[0]) - 1.
     cheb_params = chebfit(x_cheb, y_smooth, cheb_order)
-    return np.polynomial.chebyshev.chebval(x_cheb, cheb_params)        
+    return chebval(x_cheb, cheb_params)
 
-def calc_bgr(dset, qwid=0.1, nsmooth=40, cheb_order=40):             
+def calc_bgr(dset, qwid=0.1, nsmooth=40, cheb_order=40):
     return extract_background(dset.q, dset.I, smooth_width=qwid,
                               iterations=nsmooth, cheb_order=cheb_order)
 
+class WavelengthDialog(wx.Dialog):
+    """dialog for wavelength/energy"""
+    def __init__(self, parent, wavelength, callback=None):
+
+        self.parent = parent
+        self.callback = callback
+
+        wx.Dialog.__init__(self, parent, wx.ID_ANY, size=(550, 400),
+                           title="Set Wavelength / Energy")
+        self.SetFont(Font(FONTSIZE))
+        panel = GridPanel(self, ncols=3, nrows=4, pad=4, itemstyle=LEFT)
+
+        self.wids = wids = {}
+
+        opts  = dict(size=(90, -1), act_on_losefocus=True)
+        wids['wavelength'] = FloatCtrl(panel, value=wavelength, precision=7,
+                                       minval=1.0e-4, maxval=100, **opts)
+
+        en_ev = PLANCK_HC/wavelength
+        wids['energy'] = FloatCtrl(panel, value=en_ev, precision=2,
+                                   minval=50, maxval=5.e5, **opts)
 
 
-class XRD1DBrowserFrame(wx.Frame):
+        wids['wavelength'].SetAction(self.set_wavelength)
+        wids['energy'].SetAction(self.set_energy)
+
+        panel.Add(SimpleText(panel, 'Wavelength(\u212B): '),
+                  dcol=1, newrow=False)
+        panel.Add(wids['wavelength'], dcol=1)
+        panel.Add(SimpleText(panel, 'Energy (eV): '),
+                  dcol=1, newrow=True)
+        panel.Add(wids['energy'], dcol=1)
+
+        panel.Add((10, 10), newrow=True)
+
+        panel.Add(Button(panel, 'Done', size=(150, -1),
+                         action=self.onDone),  newrow=True)
+        panel.pack()
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        sizer.Add(panel, 1, LEFT, 5)
+        pack(self, sizer)
+        self.Fit()
+
+        w0, h0 = self.GetSize()
+        w1, h1 = self.GetBestSize()
+        self.SetSize((max(w0, w1)+25, max(h0, h1)+25))
+
+    def onDone(self, event=None):
+        if callable(self.callback):
+            self.callback(self.wids['wavelength'].GetValue())
+        self.Destroy()
+
+    def set_wavelength(self, value=1, event=None):
+        w = self.wids['wavelength'].GetValue()
+
+        self.wids['energy'].SetValue(PLANCK_HC/w, act=False)
+
+    def set_energy(self, value=10000, event=None):
+        w = self.wids['energy'].GetValue()
+        self.wids['wavelength'].SetValue(PLANCK_HC/w, act=False)
+
+class RenameDialog(wx.Dialog):
+    """dialog for renaming a pattern"""
+    def __init__(self, parent, name, callback=None):
+
+        self.parent = parent
+        self.callback = callback
+
+        wx.Dialog.__init__(self, parent, wx.ID_ANY, size=(550, 400),
+                           title="Rename dataset")
+        self.SetFont(Font(FONTSIZE))
+        panel = GridPanel(self, ncols=3, nrows=4, pad=4, itemstyle=LEFT)
+
+        self.wids = wids = {}
+        wids['newname'] = wx.TextCtrl(panel, value=name, size=(150, -1))
+
+        panel.Add(SimpleText(panel, 'New Name: '),  dcol=1, newrow=False)
+        panel.Add(wids['newname'], dcol=1)
+        panel.Add((10, 10), newrow=True)
+
+        panel.Add(Button(panel, 'Done', size=(150, -1),
+                         action=self.onDone),  newrow=True)
+        panel.pack()
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        sizer.Add(panel, 1, LEFT, 5)
+        pack(self, sizer)
+        self.Fit()
+
+        w0, h0 = self.GetSize()
+        w1, h1 = self.GetBestSize()
+        self.SetSize((max(w0, w1)+25, max(h0, h1)+25))
+
+    def onDone(self, event=None):
+        if callable(self.callback):
+            self.callback(self.wids['newname'].GetValue())
+        self.Destroy()
+
+class XRD1DFrame(wx.Frame):
     """browse 1D XRD patterns"""
 
-    def __init__(self, parent=None, wavelength=1.0, ponifile=None, _larch=None, **kws):
-        
+    def __init__(self, parent=None, wavelength=1.0, ponifile=None,
+                 _larch=None, **kws):
+
         wx.Frame.__init__(self, None, -1, title='1D XRD Browser',
                           style=FRAMESTYLE, size=(600, 600), **kws)
         self.parent = parent
         self.wavelength = wavelength
         self.poni = {'wavelength': 1.e-10*self.wavelength} # ! meters!
-        if ponifile is not None:
-            try:
-                self.poni.update(read_poni(ponifile))
-            except:
-                pass
+        self.pyfai_integrator = None
+
         self.larch = _larch
+        if self.larch is None:
+            self.larch_buffer = LarchFrame(_larch=None, parent=self,
+                                           is_standalone=False,
+                                           with_raise=False,
+                                           exit_on_close=False)
+
+            self.larch = self.larch_buffer.larchshell
+
         self.current_label = None
+        self.cif_browser = None
+        self.img_display = None
+        self.plot_display = None
         self.datasets = {}
         self.form = {}
         self.createMenus()
         self.build()
-        self.set_wavelength(self.wavelength)        
+        self.set_wavelength(self.wavelength)
+        if ponifile is not None:
+            self.set_ponifile(ponifile)
 
     def createMenus(self):
         fmenu = wx.Menu()
+        cmenu = wx.Menu()
+        smenu = wx.Menu()
         MenuItem(self, fmenu, "Read XY File",
                  "Read XRD 1D data from XY FIle",
                  self.onReadXY)
@@ -168,39 +280,195 @@ class XRD1DBrowserFrame(wx.Frame):
         MenuItem(self, fmenu, "Save XY File",
                  "Save XRD 1D data to XY FIle",
                  self.onSaveXY)
+        self.tiff_reader = MenuItem(self, fmenu, "Read TIFF XRD Image",
+                                    "Read XRD 2D image to be integrated",
+                                    self.onReadTIFF)
+        self.tiff_reader.Enable(self.poni.get('dist', -1) > 0)
+        fmenu.AppendSeparator()
+        MenuItem(self, fmenu, "Change Label for Current Pattern",
+                 "Rename Current Pattern",
+                 self.onRenameDataset)
 
-        fmenu.AppendSeparator()        
-        MenuItem(self, fmenu, "Read PONI Calibration File",
+        MenuItem(self, fmenu, "Remove Selected Patterns",
+                 "Remove Selected Patterns",
+                 self.remove_selected_datasets)
+
+        fmenu.AppendSeparator()
+        MenuItem(self, fmenu, "&Quit\tCtrl+Q", "Quit program", self.onClose)
+
+        MenuItem(self, smenu, "Browse AmMin Crystal Structures",
+                 "Browse Structures from Am Min Database",
+                 self.onCIFBrowse)
+
+        MenuItem(self, cmenu, "Read PONI Calibration File",
                  "Read PONI Calibration (pyFAI) FIle",
                  self.onReadPONI)
 
+        MenuItem(self, cmenu, "Set Energy / Wavelength",
+                 "Set Energy and Wavelength",
+                 self.onSetWavelength)
+
         menubar = wx.MenuBar()
         menubar.Append(fmenu, "&File")
+        menubar.Append(cmenu, "&Calibration")
+        menubar.Append(smenu, "&Search CIF Structures")
         self.SetMenuBar(menubar)
 
+
+    def onClose(self, event=None):
+        try:
+            if self.panel is not None:
+                self.panel.win_config.Close(True)
+            if self.panel is not None:
+                self.panel.win_config.Destroy()
+        except:
+            pass
+
+        for attr in ('cif_browser', 'img_display', 'plot_display'):
+            winx = getattr(self, attr, None)
+            if winx is not None:
+                try:
+                    winx.Destroy()
+                except:
+                    pass
+
+        if hasattr(self.larch.symtable, '_plotter'):
+            wx.CallAfter(self.larch.symtable._plotter.close_all_displays)
+
+        self.Destroy()
+
+    def onSetWavelength(self, event=None):
+        WavelengthDialog(self, self.wavelength, self.set_wavelength).Show()
+
     def onReadPONI(self, event=None):
         sfile = FileOpen(self, 'Read PONI (pyFAI) calibration file',
-                         defaultDir=get_cwd(),
+                         default_file='XRD.poni',
+                         default_dir=get_cwd(),
                          wildcard="PONI Files(*.poni)|*.poni|All files (*.*)|*.*")
-        
+
         if sfile is not None:
-            top, xfile = os.split(sfile)
             try:
-                self.poni.update(read_poni(path))
+                self.poni.update(read_poni(sfile))
             except:
-                pass
-        self.set_wavelength(self.poni[wavelength]*1.e10)
+                title = "Could not read PONI File"
+                message = [f"Could not read PONI file {sfile}"]
+                ExceptionPopup(self, title, message)
+
+            top, xfile = os.path.split(sfile)
+            os.chdir(top)
+
+            try:
+                self.pyfai_integrator = AzimuthalIntegrator(**self.poni)
+            except:
+                self.pyfai_integrator = None
+
+            self.tiff_reader.Enable(self.pyfai_integrator is not None)
+
+        self.set_wavelength(self.poni['wavelength']*1.e10)
 
     def onReadXY(self, event=None):
         sfile = FileOpen(self, 'Read XY Data',
-                         defaultDir=get_cwd(),
+                         default_file='XRD.xy',
+                         default_dir=get_cwd(),
                          wildcard=XYWcards)
         if sfile is not None:
-            print(' would read ', sfile)
-            top, xfile = os.split(sfile)
-            dxrd = xrd1d(file=sfile)
+            top, xfile = os.path.split(sfile)
+            os.chdir(top)
+            dxrd = xrd1d(file=sfile, wavelength=self.wavelength)
             self.add_data(dxrd, label=xfile)
-           
+
+    def onReadTIFF(self, event=None):
+        sfile = FileOpen(self, 'Read TIFF XRD Image',
+                         default_file='XRD.tiff',
+                         default_dir=get_cwd(),
+                         wildcard=TIFFWcards)
+        if sfile is not None:
+            if self.pyfai_integrator is None:
+                try:
+                    self.pyfai_integrator = AzimuthalIntegrator(**self.poni)
+                except:
+                    title = "Could not create pyFAI integrator: bad PONI data?"
+                    message = [f"Could not create pyFAI integrator"]
+                    ExceptionPopup(self, title, message)
+            if self.pyfai_integrator is None:
+                return
+
+            img =  tifffile.imread(sfile)
+            img = img[::-1, :]
+            if (img.max() > MAXVAL_INT16) and (img.max() < MAXVAL_INT16 + 64):
+                #probably really 16bit data
+                img[np.where(img>MAXVAL_INT16)] = 0
+            else:
+                img[np.where(img>MAXVAL)] = 0
+            img[np.where(img<-1)] = -1
+            # print("read tiff ", img.shape, img.min(), img.max())
+
+            imd = self.get_imdisplay()
+            imd.display(img, colomap='gray', auto_contrast=True)
+
+            integrate = self.pyfai_integrator.integrate1d
+            q, ix = integrate(img, 2048, method='csr', unit='q_A^-1',
+                              correctSolidAngle=True,
+                              polarization_factor=0.999)
+
+            top, fname = os.path.split(sfile)
+            dxrd = xrd1d(label=fname, x=q, I=ix, xtype='q', wavelength=self.wavelength)
+            dxrd.file = fname
+            self.add_data(dxrd, label=fname)
+
+
+    def onCIFBrowse(self, event=None):
+        shown = False
+        if self.cif_browser is not None:
+            try:
+                self.cif_browser.Raise()
+                shown = True
+            except:
+                del self.cif_browser
+                shown = False
+        if not shown:
+            self.cif_browser = CIFFrame(usecif_callback=self.onLoadCIF,
+                                        _larch=self.larch)
+            self.cif_browser.Raise()
+
+    def onLoadCIF(self, cif=None):
+        if cif is None:
+            return
+        t0 = time.time()
+
+        energy = E_from_lambda(self.wavelength)
+
+        sfact = cif.get_structure_factors(wavelength=self.wavelength)
+        try:
+            self.cif_browser.cifdb.set_hkls(self.current_cif.ams_id, sfact.hkls)
+        except:
+            pass
+
+        mineral = getattr(cif, 'mineral', None)
+        label = getattr(mineral, 'name', '')
+        if len(label) < 0:
+            label = getattr(cif, 'formula', '')
+        cifid = getattr(cif, 'ams_id', '')
+        if len(label) < 1 and len(cifid) > 0:
+            label = 'CIF:{cifid}'
+        else:
+            label = f'{label}, CIF:{cifid}'
+
+        try:
+            q = self.datasets[self.current_label].q
+        except:
+            q = np.linspace(0, 10, 2048)
+
+        sigma = 2.5*(q[1] - q[0])
+
+        intensity = q*0.0
+        for cen, amp in zip(sfact.q, sfact.intensity):
+            intensity += gaussian(q, amplitude=amp, center=cen, sigma=sigma)
+
+        xdat = xrd1d(label=label, energy=energy, wavelength=self.wavelength)
+        xdat.set_xy_data(np.array([q, intensity/max(intensity)]), 'q')
+        self.add_data(xdat, label=label)
+
 
     def onSaveXY(self, event=None):
         fname = fix_filename(self.current_label.replace('.', '_') + '.xy')
@@ -210,7 +478,7 @@ class XRD1DBrowserFrame(wx.Frame):
 
         label = self.current_label
         dset = self.datasets[label]
-            
+
         xscale = self.wids['xscale'].GetSelection()
         xlabel = self.wids['xscale'].GetStringSelection()
         xdat = dset.twth
@@ -223,16 +491,19 @@ class XRD1DBrowserFrame(wx.Frame):
         wavelength = PLANCK_HC/(dset.energy*1000.0)
         buff = [f"# XY data from {label}",
                 f"# wavelength (Ang) = {gformat(wavelength)}",
-                "#-------------------------------------",
-                f"# {xlabel}    Intensity"]
+                "# Calibration data from pyFAI:"]
+        for key, value in self.poni.items():
+            buff.append(f"#    {key}: {value}")
+        buff.append("#-------------------------------------")
+        buff.append(f"# {xlabel}    Intensity")
 
         for x, y in zip(xdat, ydat):
-            buff.append(f" {gformat(x)} {gformat(y)}")
+            buff.append(f"  {gformat(x, 13)}  {gformat(y, 13)}")
         buff.append('')
         with open(sfile, 'w') as fh:
             fh.write('\n'.join(buff))
-       
-            
+
+
     def build(self):
         sizer = wx.GridBagSizer(3, 3)
         sizer.SetVGap(3)
@@ -316,34 +587,34 @@ class XRD1DBrowserFrame(wx.Frame):
         wids['bkg_qwid'] = FloatSpin(panel, value=0.1, size=(90, -1), digits=2,
                                      increment=0.01,
                                      min_val=0.001, max_val=5, action=self.on_bkg)
-        wids['bkg_nsmooth'] = FloatSpin(panel, value=30, size=(90, -1), 
-                                        digits=0, min_val=2, max_val=200, action=self.on_bkg)
-        wids['bkg_porder'] = FloatSpin(panel, value=40, size=(90, -1), 
-                                        digits=0, min_val=2, max_val=200, action=self.on_bkg)
+        wids['bkg_nsmooth'] = FloatSpin(panel, value=30, size=(90, -1),
+                                        digits=0, min_val=2, max_val=100, action=self.on_bkg)
+        wids['bkg_porder'] = FloatSpin(panel, value=40, size=(90, -1),
+                                        digits=0, min_val=2, max_val=100, action=self.on_bkg)
 
         def CopyBtn(name):
-            return Button(panel, 'Copy to Seleceted', size=(100, -1),
+            return Button(panel, 'Copy to Seleceted', size=(150, -1),
                           action=partial(self.onCopyAttr, name))
 
         wids['bkg_copy'] = CopyBtn('bkg')
         wids['scale_copy'] = CopyBtn('scale_method')
-        
+
         def slabel(txt):
             return wx.StaticText(panel, label=txt)
-        
+
         panel.Add(title, style=LEFT, dcol=5)
         panel.Add(self.plotsel, newrow=True)
         panel.Add(wids['plotsel'], dcol=2)
-        panel.Add(slabel(' X scale: '), style=LEFT)
-        panel.Add(wids['xscale'])
+        panel.Add(slabel(' X scale: '), dcol=2, style=LEFT)
+        panel.Add(wids['xscale'], style=RIGHT)
 
         panel.Add(self.plotone, newrow=True)
         panel.Add(wids['plotone'], dcol=2)
-        panel.Add(slabel(' Plot Window: '))
-        panel.Add(wids['plot_win'])
-        
+        panel.Add(slabel(' Plot Window: '), dcol=2)
+        panel.Add(wids['plot_win'], style=RIGHT)
+
         panel.Add((5, 5))
-        panel.Add(HLine(panel, size=(550, 3)), dcol=5, newrow=True)
+        panel.Add(HLine(panel, size=(550, 3)), dcol=6, newrow=True)
         panel.Add((5, 5))
 
 
@@ -352,34 +623,35 @@ class XRD1DBrowserFrame(wx.Frame):
         panel.Add(wids['auto_scale'])
         panel.Add(slabel(' Scaling Method: '), style=LEFT, newrow=True)
         panel.Add(wids['scale_method'], dcol=3)
-        panel.Add(wids['scale_copy'])
-        
+        panel.Add(wids['scale_copy'], dcol=2, style=RIGHT)
+
         panel.Add((5, 5))
-        panel.Add(HLine(panel, size=(550, 3)), dcol=5, newrow=True)
+        panel.Add(HLine(panel, size=(550, 3)), dcol=6, newrow=True)
         panel.Add((5, 5))
 
-        panel.Add(slabel(' Background Subtraction Parameters: '), dcol=2, style=LEFT, newrow=True)
-        panel.Add(wids['bkg_copy'])
+        panel.Add(slabel(' Background Subtraction Parameters: '), dcol=3, style=LEFT, newrow=True)
+        panel.Add(wids['bkg_copy'], dcol=3, style=RIGHT)
+
         panel.Add(slabel(' Q width (\u212B\u207B\u00B9): '), style=LEFT, newrow=True)
-        panel.Add(wids['bkg_qwid'])        
+        panel.Add(wids['bkg_qwid'])
         panel.Add(slabel(' Smoothing Steps: '), style=LEFT, newrow=True)
         panel.Add(wids['bkg_nsmooth'], dcol=2)
-        panel.Add(slabel(' Polynomial Order: '), style=LEFT, newrow=False)
-        panel.Add(wids['bkg_porder'])                
+        panel.Add(slabel(' Polynomial Order: '), style=LEFT, newrow=True)
+        panel.Add(wids['bkg_porder'])
 
         panel.Add((5, 5))
-        panel.Add(HLine(panel, size=(550, 3)), dcol=5, newrow=True)
+        panel.Add(HLine(panel, size=(550, 3)), dcol=6, newrow=True)
         panel.Add((5, 5))
 
-        panel.Add(slabel(' Calibration, Calculated XRD Patterns: '), dcol=4, style=LEFT, newrow=True)
+        panel.Add(slabel(' Calibration, Calculated XRD Patterns: '), dcol=6, style=LEFT, newrow=True)
         panel.Add(slabel(' X-ray Energy (eV): '), style=LEFT, newrow=True)
         panel.Add(wids['energy_ev'], dcol=1)
         panel.Add(slabel(' Wavelength (\u212B): '), style=LEFT, newrow=False)
-        panel.Add(wids['wavelength'], dcol=1)
+        panel.Add(wids['wavelength'], dcol=2)
 
 
         panel.Add((5, 5))
-        
+
         panel.pack()
 
         sizer = wx.BoxSizer(wx.VERTICAL)
@@ -394,14 +666,39 @@ class XRD1DBrowserFrame(wx.Frame):
         mainsizer = wx.BoxSizer(wx.VERTICAL)
         mainsizer.Add(splitter, 1, wx.GROW|wx.ALL, 5)
         pack(self, mainsizer)
-        self.SetSize( (850, 400))
+        self.SetSize((875, 450))
 
         self.Show()
         self.Raise()
 
-    def set_wavelength(self, w):
-        self.wids['wavelength'].SetLabel("%.6f" % w)
-        self.wids['energy_ev'].SetLabel("%.1f" % (PLANCK_HC/w))
+    def set_ponifile(self, ponifile):
+        "set poni from datafile"
+        try:
+            self.set_poni(read_poni(ponifile))
+        except:
+            pass
+
+    def set_poni(self, poni):
+        "set poni from dict"
+        try:
+            self.poni.update(poni)
+            self.set_wavelength(self.poni['wavelength']*1.e10)
+            self.tiff_reader.Enable(self.poni.get('dist', -1) > 0)
+        except:
+            pass
+
+        try:
+            self.pyfai_integrator = AzimuthalIntegrator(**self.poni)
+        except:
+            self.pyfai_integrator = None
+
+
+    def set_wavelength(self, value):
+        self.wavelength = value
+        self.wids['wavelength'].SetLabel("%.6f" % value)
+        self.wids['energy_ev'].SetLabel("%.1f" % (PLANCK_HC/value))
+        for key, dset in self.datasets.items():
+            dset.set_wavelength(value)
 
     def onCopyAttr(self, name=None, event=None):
         # print("Copy ", name, event)
@@ -427,7 +724,7 @@ class XRD1DBrowserFrame(wx.Frame):
                     # print("redo scale for ", label)
                     self.scale_data(dset, with_plot=False)
 
-                
+
     def onSelNone(self, event=None):
         self.filelist.select_none()
 
@@ -451,7 +748,7 @@ class XRD1DBrowserFrame(wx.Frame):
             self.wids['plotone'].SetSelection(1)
         else:
             self.onPlotOne()
-        
+
     def show_dataset(self, event=None, label=None):
         # print('show xd1d ', event, label)
         if label is None and event is not None:
@@ -487,9 +784,9 @@ class XRD1DBrowserFrame(wx.Frame):
         self.wids['bkg_qwid'].SetValue(dset.bkg_qwid)
         self.wids['bkg_nsmooth'].SetValue(dset.bkg_nsmooth)
         self.wids['bkg_porder'].SetValue(dset.bkg_porder)
-        
+
         self.onPlotOne(label=label)
-        
+
     def set_scale(self, event=None, value=-1.0):
         label = self.current_label
         if label not in self.datasets:
@@ -505,13 +802,13 @@ class XRD1DBrowserFrame(wx.Frame):
         dset = self.datasets[label]
         dset.auto_scale = self.wids['auto_scale'].IsChecked()
         self.wids['scale_method'].Enable(dset.auto_scale)
-            
+
         if dset.auto_scale:
             self.scale_data(dset, with_plot=True)
 
     def scale_data(self, dset, with_plot=True):
         meth_name = self.wids['scale_method'].GetStringSelection()
-        
+
         meth = dset.scale_method = SCALE_METHODS[meth_name]
 
         # if not meth.startswith('raw'):
@@ -523,59 +820,111 @@ class XRD1DBrowserFrame(wx.Frame):
         dset.bkg_qwid = qwid
         dset.bkg_nmsooth = nsmooth
         dset.bkg_porder = cheb_order
-                                
+
         scale =  -1
         if meth == 'raw_max':
             scale = dset.I.max()
         elif meth == 'raw_mean':
-            scale = dset.I.mean()                
+            scale = dset.I.mean()
         elif meth == 'sub_max':
-            scale = (dset.I - dset.bkgd).max()                
+            scale = (dset.I - dset.bkgd).max()
         elif meth == 'sub_mean':
             scale = (dset.I - dset.bkgd).mean()
         elif meth == 'bkg_max':
-            scale = (dset.bkgd).max()                
+            scale = (dset.bkgd).max()
         elif meth == 'bkg_mean':
             scale = (dset.bkgd).mean()
-            
+
         if scale > 0:
             self.wids['scale'].SetValue(scale)
             if with_plot:
                 self.onPlotOne()
 
-    def remove_dataset(self, event=None):
-        print('remove dataset ', event.GetString())
+    def rename_dataset(self, newlabel):
+        dset = self.datasets.pop(self.current_label)
+        dset.label = newlabel
+        self.datasets[newlabel] = dset
+        self.current_label = newlabel
+
+        self.filelist.Clear()
+        for name in self.datasets:
+            self.filelist.Append(name)
+
+
+    def onRenameDataset(self, event=None):
+        RenameDialog(self, self.current_label, self.rename_dataset).Show()
+
+
+    def remove_dataset(self, dname=None, event=None):
+        if dname in self.datasets:
+            self.datasets.pop(dname)
+
+        self.filelist.Clear()
+        for name in self.datasets:
+            self.filelist.Append(name)
+
+
+    def remove_selected_datasets(self, event=None):
+        sel = []
+        for checked in self.filelist.GetCheckedStrings():
+            sel.append(str(checked))
+        if len(sel) < 1:
+            return
+
+        dlg = RemoveDialog(self, sel)
+        res = dlg.GetResponse()
+        dlg.Destroy()
+
+        if res.ok:
+            all = self.filelist.GetItems()
+            for dname in sel:
+                self.datasets.pop(dname)
+                all.remove(dname)
+
+            self.filelist.Clear()
+            for name in all:
+                self.filelist.Append(name)
+
+    def get_imdisplay(self, win=1):
+        wintitle='XRD Image Window %i' % win
+        opts = dict(wintitle=wintitle, win=win, image=True)
+        self.img_display = self.larch.symtable._plotter.get_display(**opts)
+        return self.img_display
 
     def get_display(self, win=1, stacked=False):
         wintitle='XRD Plot Window %i' % win
         opts = dict(wintitle=wintitle, stacked=stacked, win=win, linewidth=3)
-        return self.larch.symtable._plotter.get_display(**opts)
+        self.plot_display = self.larch.symtable._plotter.get_display(**opts)
+        return self.plot_display
 
     def plot_dset(self, dset, plottype, newplot=True):
         win    = int(self.wids['plot_win'].GetStringSelection())
         xscale = self.wids['xscale'].GetSelection()
-        xlabel = self.wids['xscale'].GetStringSelection()
+        opts = {'show_legend': True, 'xmax': None,
+                'xlabel':  self.wids['xscale'].GetStringSelection(),
+                'ylabel':'Scaled Intensity',
+                'label': dset.label}
+
         xdat = dset.q
         if xscale == 2:
            xdat = dset.d
+           opts['xmax'] = min(12.0, max(xdat))
         elif xscale == 1:
             xdat = dset.twth
 
         ydat = 1.0*dset.I/dset.scale
-        ylabel = 'Scaled Intensity'
         if plottype == 'sub':
             ydat = 1.0*(dset.I-dset.bkgd)/dset.scale
-            ylabel = 'Scaled (Intensity - Background)'
+            opts['ylabel'] = 'Scaled (Intensity - Background)'
 
         pframe = self.get_display(win=win)
         plot = pframe.plot if newplot else pframe.oplot
-        plot(xdat, ydat, xlabel=xlabel, ylabel=ylabel,
-             label=dset.label, show_legend=True)
+        plot(xdat, ydat, **opts)
         if plottype == 'raw+bkg':
             y2dat = 1.0*dset.bkgd/dset.scale
-            ylabel = 'Scaled Intensity with Background'
-            pframe.oplot(xdat, y2dat, xlabel=xlabel, ylabel=ylabel,
-                         label='background', show_legend=True)
+            opts['ylabel'] = 'Scaled Intensity with Background'
+            opts['label'] = 'background'
+            pframe.oplot(xdat, y2dat, **opts)
 
     def onPlotOne(self, event=None, label=None):
         if label is None:
@@ -584,16 +933,16 @@ class XRD1DBrowserFrame(wx.Frame):
             return
         dset = self.datasets[label]
         self.last_plot_type = 'one'
-        plottype = PLOT_TYPES.get(self.wids['plotone'].GetStringSelection(), 'raw')        
+        plottype = PLOT_TYPES.get(self.wids['plotone'].GetStringSelection(), 'raw')
         self.plot_dset(dset, plottype, newplot=True)
-        wx.CallAfter(self.SetFocus)        
+        wx.CallAfter(self.SetFocus)
 
     def onPlotSel(self, event=None):
         labels = self.filelist.GetCheckedStrings()
         if len(labels) < 1:
             return
         self.last_plot_type = 'multi'
-        plottype = PLOT_TYPES.get(self.wids['plotsel'].GetStringSelection(), 'raw')        
+        plottype = PLOT_TYPES.get(self.wids['plotsel'].GetStringSelection(), 'raw')
         newplot = True
         for label in labels:
             dset = self.datasets.get(label, None)
@@ -601,7 +950,7 @@ class XRD1DBrowserFrame(wx.Frame):
                 self.plot_dset(dset, plottype, newplot=newplot)
                 newplot = False
         wx.CallAfter(self.SetFocus)
-        
+
     def onPlotEither(self, event=None):
         if self.last_plot_type == 'multi':
             self.onPlotSel(event=event)
@@ -612,9 +961,18 @@ class XRD1DBrowserFrame(wx.Frame):
         if label is None:
             label = 'XRD pattern'
         if label in self.datasets:
-            print('label alread in datasets: ', label )
+            print('label already in datasets: ', label )
         else:
             self.filelist.Append(label)
             self.datasets[label] = dataset
             self.show_dataset(label=label)
 
+class XRD1DApp(LarchWxApp):
+    def __init__(self, **kws):
+        LarchWxApp.__init__(self)
+
+    def createApp(self):
+        frame = XRD1DFrame()
+        frame.Show()
+        self.SetTopWindow(frame)
+        return True
