@@ -8,6 +8,7 @@ except ImportError:
     from collections import Iterable
 from copy import copy, deepcopy
 from functools import partial
+import ast
 import numpy as np
 from numpy import array, arange, interp, pi, zeros, sqrt, concatenate
 
@@ -17,11 +18,12 @@ from lmfit import Parameters, Parameter, Minimizer, fit_report
 
 from larch import Group, isNamedClass
 from larch.utils import fix_varname, gformat
+from larch.utils.strutils import b32hash, random_varname
 from ..math import index_of, realimag, complex_phase, remove_nans
 from ..fitting import (correlated_values, eval_stderr, ParameterGroup,
                        group2params, params2group, isParameter)
 
-from .xafsutils import set_xafsGroup
+from .xafsutils import set_xafsGroup, gfmt
 from .xafsft import xftf_fast, xftr_fast, ftwindow
 from .feffdat import FeffPathGroup, ff2chi
 
@@ -228,10 +230,14 @@ class TransformGroup(Group):
         return (out*self._cauchymask)[self._cauchyslice]
 
 class FeffitDataSet(Group):
-    def __init__(self, data=None, paths=None, transform=None,
-                 epsilon_k=None, _larch=None, pathlist=None, **kws):
+
+    def __init__(self, data=None, paths=None, transform=None, epsilon_k=None,
+                 refine_bkg=False, pathlist=None, model=None, _larch=None,
+                 **kws):
+
         self._larch = _larch
         Group.__init__(self, **kws)
+        self.refine_bkg = refine_bkg
 
         if paths is None and pathlist is not None:  # legacy
             paths = pathlist
@@ -242,34 +248,64 @@ class FeffitDataSet(Group):
             self.paths = {path.label: copy(path) for path in paths}
         else:
             self.paths = {}
-
         # make datagroup from passed in data: copy of k, chi, delta_chi, epsilon_k
         self.data = Group(__name__='Feffit DatasSet from %s' % repr(data),
                           groupname=getattr(data, 'groupname', repr(data)),
                           filename=getattr(data, 'filename', repr(data)),
-                          k=data.k.copy(), chi=data.chi.copy())
+                          k=data.k[:]*1.0, chi=data.chi[:]*1.0)
         if hasattr(data, 'config'):
             self.data.config = deepcopy(data.config)
         else:
             self.data.config = Group()
-
-        self.data.delta_chi = getattr(data, 'delta_chi', None)
-
         self.data.epsilon_k = getattr(data, 'epsilon_k', epsilon_k)
         if epsilon_k is not None:
             self.data.epsilon_k = epsilon_k
 
+        dat_attrs = ['delta_chi', 'r', 'chir_mag', 'chir_re', 'chir_im']
+        if data is not None:
+            dat_attrs.extend(dir(data))
+        for attr in dat_attrs:
+            if attr not in ('feffit_history',) and not hasattr(self.data, attr):
+                setattr(self.data, attr, getattr(data, attr, None))
+
         if transform is None:
             transform = TransformGroup()
         else:
             trasform = copy(transform)
         self.transform = transform
 
-        self.model = Group(__name__='Feffit Model for %s' % repr(data))
-        self.model.k = None
+        if model is None:
+            self.model = Group(__name__='Feffit Model for %s' % repr(data))
+            self.model.k = None
+        else:
+            self.model = model
+        self.hashkey = None
         self.__chi = None
         self.__prepared = False
 
+    def _generate_hashkey(self, other_hashkeys=None):
+        """generate hash for dataset"""
+        if self.hashkey is not None:
+            return
+        hlen = 10
+        dat = [self.data.ek0, self.data.e0, self.data.rbkg]
+        for arr in (self.data.energy, self.data.norm, self.data.chi):
+            dat.extend([arr.min(), arr.max(), arr.mean(),
+                        (arr**2).mean(), len(arr)])
+            dat.extend(arr[:30:3])
+        s = "|".join([gformat(x) for x in dat])
+        self.hashkey = f"d{(b32hash(s)[:hlen].lower())}"
+        # may need to look for hash collisions: if there is a collision,
+        # it is probably the same dataset, so just go witha
+        if other_hashkeys is not None:
+            ntry = 0
+            while self.hashkey in other_hashkeys:
+                ntry += 1
+                if ntry > 1e6:
+                    ntry = 0
+                    hlen += 1
+                self.hashkey = f"d{random_varname(hlen)}"
+
     def __repr__(self):
         return '<FeffitDataSet Group: %s>' % self.__name__
 
@@ -277,15 +313,21 @@ class FeffitDataSet(Group):
         return FeffitDataSet(data=copy(self.data),
                              paths=self.paths,
                              transform=self.transform,
+                             refine_bkg=self.refine_bkg,
+                             epsilon_k=self.data.epsilon_k,
+                             model=self.model,
                              _larch=self._larch)
 
     def __deepcopy__(self, memo):
         return FeffitDataSet(data=deepcopy(self.data),
                              paths=self.paths,
                              transform=self.transform,
+                             refine_bkg=self.refine_bkg,
+                             epsilon_k=self.data.epsilon_k,
+                             model=self.model,
                              _larch=self._larch)
 
-    def prepare_fit(self, params):
+    def prepare_fit(self, params, other_hashkeys=None):
         """prepare for fit with this dataset"""
         trans = self.transform
         trans.make_karrays()
@@ -329,9 +371,15 @@ class FeffitDataSet(Group):
             if path.spline_coefs is None:
                 path.create_spline_coefs()
 
+        self._generate_hashkey(other_hashkeys=other_hashkeys)
+        self.bkg_spline = {}
+        if self.refine_bkg:
+            self.n_spline = 1 + 2*(trans.rmin)*(trans.kmax-trans.kmin)/pi
+            self.n_idp = 1 + 2*(trans.rmax)*(trans.kmax-trans.kmin)/pi
         self.__prepared = True
 
 
+
     def estimate_noise(self, chi=None, rmin=15.0, rmax=30.0, all_kweights=True):
         """estimage noise in a chi spectrum from its high r components"""
         trans = self.transform
@@ -532,7 +580,8 @@ def feffit_transform(_larch=None, **kws):
     """
     return TransformGroup(_larch=_larch, **kws)
 
-def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **kws):
+def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True,
+           fix_unused_variables=True,  _larch=None, **kws):
     """execute a Feffit fit: a fit of feff paths to a list of datasets
 
     Parameters:
@@ -541,7 +590,8 @@ def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **
       datasets:     Feffit Dataset group or list of Feffit Dataset group.
       rmax_out:     maximum R value to calculate output arrays.
       path_output:  Flag to set whether all Path outputs should be written.
-
+      fix_unused_variables: Flag for whether to set `vary=False` for unused
+                    variable parameters.  Otherwise, a warning will be printed.
     Returns:
     ---------
       a fit results group.  This will contain subgroups of:
@@ -576,6 +626,7 @@ def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **
         if isinstance(wpar, Parameter):
             setattr(wpar, 'skip', getattr(opar, 'skip', False))
 
+
     params = group2params(work_paramgroup)
 
     def _resid(params, datasets=None, pargroup=None, **kwargs):
@@ -585,28 +636,42 @@ def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **
     if isNamedClass(datasets, FeffitDataSet):
         datasets = [datasets]
 
+    # we need unique dataset hashes if refine_bkg is used
+    dset_hashkeys = []
     for ds in datasets:
         if not isNamedClass(ds, FeffitDataSet):
             print( "feffit needs a list of FeffitDataSets")
             return
-        ds.prepare_fit(params=params)
+        ds.prepare_fit(params=params, other_hashkeys=dset_hashkeys)
+        dset_hashkeys.append(ds.hashkey)
+    # try to identify variable Parameters that are not actually used
+    vars, exprs = [], []
+    for p in params.values():
+        if p.vary:
+            vars.append(p.name)
+        elif p.expr is not None:
+            exprs.append(p.expr)
 
-#     n_idp = 0
-#     n_data = 0
-#     n_varys = len([p for p in params.values() if p.vary])
-#
-#     for ds in datasets:
-#         n_idp += ds.n_idp
-#         r1 = ds._residual(params)
-#         n_data += len(r1)
-#
+    for expr in exprs:
+         for node in ast.walk(ast.parse(expr)):
+                if isinstance(node, ast.Name):
+                    if node.id in vars:
+                        vars.remove(node.id)
+    if len(vars) > 0:
+        if fix_unused_variables:
+            for v in vars:
+                params[v].vary = False
+        else:
+            vlist = ', '.join(vars)
+            print(f"Feffit Warning: unused variables: {vlist}")
+
+    # run fit
     fit = Minimizer(_resid, params,
                     fcn_kws=dict(datasets=datasets, pargroup=work_paramgroup),
                     scale_covar=False, **fit_kws)
 
     result = fit.leastsq()
     params2group(result.params, work_paramgroup)
-
     dat = concatenate([d._residual(work_paramgroup, data_only=True) for d in datasets])
 
     n_idp = 0
@@ -724,11 +789,11 @@ def feffit_report(result, min_correl=0.1, with_paths=True, _larch=None):
     out.append('   nvarys, npts       =  %i, %i' % (result.nvarys,
                                                    result.ndata))
     out.append('   n_independent      =  %.3f'  % (result.n_independent))
-    out.append('   chi_square         = %s'  % gformat(result.chi_square))
-    out.append('   reduced chi_square = %s'  % gformat(result.chi2_reduced))
-    out.append('   r-factor           = %s'  % gformat(result.rfactor))
-    out.append('   Akaike info crit   = %s'  % gformat(result.aic))
-    out.append('   Bayesian info crit = %s'  % gformat(result.bic))
+    out.append('   chi_square         = %s'  % gfmt(result.chi_square))
+    out.append('   reduced chi_square = %s'  % gfmt(result.chi2_reduced))
+    out.append('   r-factor           = %s'  % gfmt(result.rfactor))
+    out.append('   Akaike info crit   = %s'  % gfmt(result.aic))
+    out.append('   Bayesian info crit = %s'  % gfmt(result.bic))
     out.append(' ')
 
     if len(datasets) == 1:
@@ -745,20 +810,20 @@ def feffit_report(result, min_correl=0.1, with_paths=True, _larch=None):
             if isinstance(ds.epsilon_k[0], np.ndarray):
                 msg = []
                 for eps in ds.epsilon_k:
-                    msg.append('Array(mean=%s, std=%s)' % (gformat(eps.mean()).strip(),
-                                                           gformat(eps.std()).strip()))
+                    msg.append('Array(mean=%s, std=%s)' % (gfmt(eps.mean()).strip(),
+                                                           gfmt(eps.std()).strip()))
                 eps_k = ', '.join(msg)
             else:
-                eps_k = ', '.join([gformat(eps).strip() for eps in ds.epsilon_k])
-            eps_r = ', '.join([gformat(eps).strip() for eps in ds.epsilon_r])
+                eps_k = ', '.join([gfmt(eps).strip() for eps in ds.epsilon_k])
+            eps_r = ', '.join([gfmt(eps).strip() for eps in ds.epsilon_r])
             kweigh = ', '.join(['%i' % kwe for kwe in tr.kweight])
         else:
             if isinstance(ds.epsilon_k, np.ndarray):
-                eps_k = 'Array(mean=%s, std=%s)' % (gformat(ds.epsilon_k.mean()).strip(),
-                                                    gformat(ds.epsilon_k.std()).strip())
+                eps_k = 'Array(mean=%s, std=%s)' % (gfmt(ds.epsilon_k.mean()).strip(),
+                                                    gfmt(ds.epsilon_k.std()).strip())
             else:
-                eps_k = gformat(ds.epsilon_k)
-            eps_r = gformat(ds.epsilon_r).strip()
+                eps_k = gfmt(ds.epsilon_k)
+            eps_r = gfmt(ds.epsilon_r).strip()
             kweigh = '%i' % tr.kweight
         out.append('   fit space          = \'%s\''  % (tr.fitspace))
         out.append('   r-range            = %.3f, %.3f' % (tr.rmin, tr.rmax))
@@ -786,18 +851,18 @@ def feffit_report(result, min_correl=0.1, with_paths=True, _larch=None):
             if par.vary:
                 stderr = 'unknown'
                 if par.stderr is not None:
-                    stderr = gformat(par.stderr)
-                out.append(varformat % (name, gformat(par.value),
-                                        stderr, gformat(par.init_value)))
+                    stderr = gfmt(par.stderr)
+                out.append(varformat % (name, gfmt(par.value),
+                                        stderr, gfmt(par.init_value)))
 
             elif par.expr is not None:
                 stderr = 'unknown'
                 if par.stderr is not None:
-                    stderr = gformat(par.stderr)
-                out.append(exprformat % (name, gformat(par.value),
+                    stderr = gfmt(par.stderr)
+                out.append(exprformat % (name, gfmt(par.value),
                                          stderr, par.expr))
             else:
-                out.append(fixformat % (name, gformat(par.value)))
+                out.append(fixformat % (name, gfmt(par.value)))
 
     covar_vars = result.var_names
     if len(covar_vars) > 0:
