@@ -27,12 +27,14 @@ import os
 import re
 import time
 import json
+from io import StringIO
 from string import ascii_letters
 from base64 import b64encode, b64decode
 from collections import namedtuple
+from gzip import GzipFile
 import requests
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
-
+import atexit
 import numpy as np
 
 from sqlalchemy import MetaData, create_engine, func, text, and_, Table
@@ -40,29 +42,27 @@ from sqlalchemy import __version__ as sqla_version
 from sqlalchemy.sql import select as sqla_select
 from sqlalchemy.orm import sessionmaker
 
-try:
-    from pymatgen.io.cif import CifParser
-    HAS_CIFPARSER = True
-except IOError:
-    HAS_CIFPARSER = False
+
+from .amcsd_utils import (make_engine, isAMCSD, put_optarray, get_optarray,
+                          PMG_CIF_OPTS, CifParser, SpacegroupAnalyzer)
 
 from xraydb.chemparser import chemparse
+from xraydb import f0, f1_chantler, f2_chantler
 
-from .amcsd_utils import (make_engine, isAMCSD, put_optarray, get_optarray)
-from .xrd_cif import XRDCIF, elem_symbol
+
+from .xrd_tools import generate_hkl, d_from_hkl, twth_from_q, E_from_lambda
 from .cif2feff import cif2feffinp
-from ..utils import isotime
+from ..utils import isotime, mkdir
+from ..utils.strutils import version_ge, bytes2str
+from ..utils.physical_constants import TAU, ATOM_SYMS
 from ..site_config import user_larchdir
 from .. import logger
-from larch.utils.strutils import version_ge
-
-CifPublication = namedtuple('CifPublication', ('id', 'journalname', 'year',
-                                            'volume', 'page_first',
-                                            'page_last', 'authors'))
 
 _CIFDB = None
+ALL_HKLS = None
 AMCSD_TRIM = 'amcsd_cif1.db'
 AMCSD_FULL = 'amcsd_cif2.db'
+
 SOURCE_URLS = ('https://docs.xrayabsorption.org/databases/',
                'https://millenia.cars.aps.anl.gov/xraylarch/downloads/')
 
@@ -75,6 +75,74 @@ CIF_TEXTCOLUMNS = ('formula', 'compound', 'pub_title', 'formula_title', 'a',
                    'atoms_aniso_u23', 'qdat','url', 'hkls')
 
 
+
+CifPublication = namedtuple('CifPublication', ('id', 'journalname', 'year',
+                                            'volume', 'page_first',
+                                            'page_last', 'authors'))
+
+
+StructureFactor = namedtuple('StructureFactor', ('q', 'intensity', 'hkl',
+                                                 'twotheta', 'd',
+                                                 'wavelength', 'energy',
+                                                 'f2hkl', 'degen', 'lorentz'))
+
+
+# for packing/unpacking H, K, L to 2-character hash
+HKL_ENCODE = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ_%'
+def pack_hkl(h, k, l):
+    """pack H, K, L values into 2 character sequence of
+    printable characters for storage and transmission
+
+    H, K, L must be unsigned integers from 0 to 15
+
+    see also unpack_hkl() to reverse the process.
+    """
+    if (h > 15 or k > 15 or l > 15 or
+        h < 0  or k < 0  or l < 0):
+        raise ValueError("hkl values out of range (max=15)")
+    x = h*256 + k*16 + l
+    return HKL_ENCODE[x//64] + HKL_ENCODE[x%64]
+
+
+def unpack_hkl(hash):
+    """unpack encoded H, K, L integers packed with pack_hkl()"""
+    a, b = HKL_ENCODE.index(hash[0]), HKL_ENCODE.index(hash[1])
+    s = a*64 + b
+    t = s//16
+    return t//16, t%16, s%16
+
+
+def pack_hkl_degen(hkls, degen):
+    """pack array of H, K, L and degeneracy values into printable
+    string for storage and transmission
+    hkl must be an array or list of list/tuples for H, K, L, with
+    each H, K, L value an unsigned integers from 0 to 15
+
+    hkls and degen must be ndarrays or lists of the same length
+    see also unpack_hkl_degen() to reverse the process.
+    """
+    if len(hkls) != len(degen):
+        raise ValueError("hkls and degen must be the same length in pack_hkl_degen()")
+
+    shkl = [pack_hkl(h, k, l) for h, k, l in hkls]
+    sdegen = json.dumps(degen.tolist()).replace(' ', '')
+    return f"{''.join(shkl)}|{sdegen}"
+
+
+def unpack_hkl_degen(sinp):
+    """pack arrays of h, k, l and degeneracies from string stored by pack_hkl_degen
+    see also pack_hkl_degen()
+    """
+    shkl, sdegen = sinp.split('|')
+    n = len(shkl)//2
+    hkls = []
+    for i in range(n):
+        hkls.append(unpack_hkl(shkl[2*i:2*i+2]))
+    degen = json.loads(sdegen)
+    return np.array(hkls), np.array(degen)
+
+
+
 def select(*args):
     """wrap sqlalchemy select for version 1.3 and 2.0"""
     # print("SELECT ", args, type(args))
@@ -105,17 +173,21 @@ def parse_cif_file(filename):
         must have spacegroup
     returns dat, formula, json-dumped symm_xyz
     """
-    if not HAS_CIFPARSER:
+    if CifParser is None:
         raise ValueError("CifParser from pymatgen not available. Try 'pip install pymatgen'.")
 
-    cif = CifParser(filename)
+    cif = CifParser(filename, **PMG_CIF_OPTS)
     cifkey = list(cif._cif.data.keys())[0]
     dat = cif._cif.data[cifkey].data
 
     formula = None
     for formname in ('_chemical_formula_sum', '_chemical_formula_moiety'):
         if formname in dat:
-            formula = dat[formname]
+            try:
+                parsed_formula = chemparse(dat[formname])
+                formula = dat[formname]
+            except:
+                pass
     if formula is None and '_atom_site_type_symbol' in dat:
         comps = {}
         complist = dat['_atom_site_type_symbol']
@@ -149,18 +221,20 @@ class CifStructure():
     """representation of a Cif Structure
     """
 
-    def __init__(self, ams_id=None, publication=None, mineral=None,
+    def __init__(self, ams_id=None, ams_db=None, publication=None, mineral=None,
                  spacegroup=None, hm_symbol=None, formula_title=None,
-                 compound=None, formula=None, pub_title=None, a=None,
-                 b=None, c=None, alpha=None, beta=None, gamma=None, hkls=None,
-                 cell_volume=None, crystal_density=None, atoms_sites='<missing>',
-                 atoms_aniso_label='<missing>', atoms_x=None, atoms_y=None,
-                 atoms_z=None, atoms_occupancy=None, atoms_u_iso=None,
-                 atoms_aniso_u11=None, atoms_aniso_u22=None,
-                 atoms_aniso_u33=None, atoms_aniso_u12=None,
-                 atoms_aniso_u13=None, atoms_aniso_u23=None):
+                 compound=None, formula=None, pub_title=None, a=None, b=None,
+                 c=None, alpha=None, beta=None, gamma=None, hkls=None,
+                 cell_volume=None, crystal_density=None,
+                 atoms_sites='<missing>', atoms_aniso_label='<missing>',
+                 atoms_x=None, atoms_y=None, atoms_z=None,
+                 atoms_occupancy=None, atoms_u_iso=None, atoms_aniso_u11=None,
+                 atoms_aniso_u22=None, atoms_aniso_u33=None,
+                 atoms_aniso_u12=None, atoms_aniso_u13=None,
+                 atoms_aniso_u23=None):
 
         self.ams_id = ams_id
+        self.ams_db = ams_db
         self.publication = publication
         self.mineral = mineral
         self.spacegroup = spacegroup
@@ -192,8 +266,9 @@ class CifStructure():
         self.atoms_aniso_u13 = get_nonzero(atoms_aniso_u13)
         self.atoms_aniso_u23 = get_nonzero(atoms_aniso_u23)
         self.natoms = 0
-        self._xrdcif = None
         self._ciftext = None
+        self.pmg_pstruct = None
+        self.pmg_cstruct = None
         if atoms_sites not in (None, '<missing>'):
             self.natoms = len(atoms_sites)
 
@@ -307,13 +382,227 @@ class CifStructure():
         self._ciftext = '\n'.join(out)
         return self.ciftext
 
-    def get_structure_factors(self, wavelength=None, energy=None, qmin=0.1, qmax=9):
-        _xrdcif = XRDCIF(text=self.ciftext)
-        return  _xrdcif.structure_factors(wavelength=wavelength,
-                                          energy=energy,
-                                          hkls=self.hkls,
-                                          qmin=qmin,
-                                          qmax=qmax)
+
+    def find_hkls(self, nmax=64, qmax=10, wavelength=0.75):
+        """find the HKLs and degeneracies of the strongest reflections
+
+        this will calculate structure factors, and sort them, but the
+        purpose is really to do a filter to find the strongest HKLs that
+        can then be saved and restored for structure factor calcs using
+        only the most important HKL values.
+
+        returns hkls, degen of the nmax reflections with the highest scattered intensity
+        """
+        self.get_pmg_struct()
+
+        pstruct = self.pmg_pstruct
+        cstruct = self.pmg_cstruct
+        if pstruct is None:
+            print(f"pymatgen could not parse CIF structure for CIF {self.ams_id}")
+            return
+
+        global ALL_HKLS
+        if ALL_HKLS is None:
+            ALL_HKLS = generate_hkl(hmax=15, kmax=15, lmax=15, positive_only=False)
+
+        hkls = ALL_HKLS[:]
+        unitcell = self.get_unitcell()
+        qhkls = TAU / d_from_hkl(hkls, **unitcell)
+
+        # remove q values outside of range
+        qfilt = (qhkls < qmax)
+        qhkls = qhkls[qfilt]
+        hkls  = hkls[qfilt]
+
+        # find duplicate q-values, set degen
+        # scale up q values to better find duplicates
+        qscaled = [int(round(q*1.e9)) for q in qhkls]
+        q_unique, q_degen, hkl_unique = [], [], []
+        for i, q in enumerate(qscaled):
+            if q in q_unique:
+                q_degen[q_unique.index(q)] += 1
+            else:
+                q_unique.append(q)
+                q_degen.append(1)
+                hkl_unique.append(hkls[i])
+
+        qorder = np.argsort(q_unique)
+        qhkls  = 1.e-9*np.array(q_unique)[qorder]
+        hkls   = abs(np.array(hkl_unique)[qorder])
+        degen  = np.array(q_degen)[qorder]
+
+        # note the f2 is calculated here without resonant corrections
+        f2 = self.calculate_f2(hkls, qhkls=qhkls, wavelength=None)
+
+        # filter out very small structure factors
+        ffilt = (f2 > 1.e-6*max(f2))
+        qhkls = qhkls[ffilt]
+        hkls  = hkls[ffilt]
+        degen = degen[ffilt]
+        f2    = f2[ffilt]
+
+        # lorentz and polarization correction
+        arad = (TAU/360)*twth_from_q(qhkls, wavelength)
+        corr = (1+np.cos(arad)**2)/(np.sin(arad/2)**2*np.cos(arad/2))
+
+        intensity = f2 * degen * corr
+        ifilt = (intensity > 0.005*max(intensity))
+
+        intensity  = intensity[ifilt] / max(intensity)
+        qhkls  = qhkls[ifilt]
+        hkls   =  hkls[ifilt]
+        degen  = degen[ifilt]
+
+        # indices of peaks in descending order of intensity
+        main_peaks = np.argsort(intensity)[::-1][:nmax]
+
+        hkls_main, degen_main = hkls[main_peaks], degen[main_peaks]
+        if self.ams_db is not None:
+            self.hkls = self.ams_db.set_hkls(self.ams_id, hkls_main, degen_main)
+
+        return hkls_main, degen_main
+
+    def get_structure_factors(self, wavelength=0.75):
+        """given arrays of HKLs and degeneracies (perhaps from find_hkls(),
+        return structure factors
+
+        This is a lot like find_hkls(), but with the assumption that HKLs
+        are not to be filtered or altered.
+        """
+        if self.hkls is None:
+            self.find_hkls(nmax=64, qmax=10, wavelength=wavelength)
+
+        hkls, degen = unpack_hkl_degen(self.hkls)
+
+        self.get_pmg_struct()
+        pstruct = self.pmg_pstruct
+        if pstruct is None:
+            print(f"pymatgen could not parse CIF structure for CIF {self.ams_id}")
+            return
+
+        unitcell = self.get_unitcell()
+        dhkls = d_from_hkl(hkls, **unitcell)
+        qhkls = TAU / dhkls
+
+        # sort by q
+        qsort = np.argsort(qhkls)
+        qhkls = qhkls[qsort]
+        dhkls = dhkls[qsort]
+        hkls  = hkls[qsort]
+        degen = degen[qsort]
+
+        energy = E_from_lambda(wavelength, E_units='eV')
+
+        f2hkl = self.calculate_f2(hkls, qhkls=qhkls, wavelength=wavelength)
+
+        # lorentz and polarization correction
+        twoth = twth_from_q(qhkls, wavelength)
+        arad = (TAU/360)*twoth
+        corr = (1+np.cos(arad)**2)/(np.sin(arad/2)**2*np.cos(arad/2))
+
+        intensity = f2hkl * degen * corr
+
+        return StructureFactor(q=qhkls, intensity=intensity, hkl=hkls, d=dhkls,
+                               f2hkl=f2hkl, twotheta=twoth, degen=degen,
+                               lorentz=corr, wavelength=wavelength,
+                               energy=energy)
+
+
+    def calculate_f2(self, hkls, qhkls=None, energy=None, wavelength=None):
+        """calculate F*F'.
+
+        If wavelength (in Ang) or energy (in eV) is not None, then
+        resonant corrections will be included.
+        """
+        if qhkls is None:
+            unitcell = self.get_unitcell()
+            qhkls = TAU / d_from_hkl(hkls, **unitcell)
+        sq = qhkls/(2*TAU)
+        sites = self.get_sites()
+
+        if energy is None and wavelength is not None:
+            energy = E_from_lambda(wavelength, E_units='eV')
+
+        # get f0 and resonant scattering factors
+        f0vals, f1vals, f2vals = {}, {}, {}
+        for elem in sites.keys():
+            if elem not in f0vals:
+                f0vals[elem] = f0(elem, sq)
+                if energy is not None:
+                    f1vals[elem] = f1_chantler(elem, energy)
+                    f2vals[elem] = f2_chantler(elem, energy)
+
+        # and f2
+        f2 = np.zeros(len(hkls))
+        for i, hkl in enumerate(hkls):
+            fsum = 0.
+            for elem in f0vals:
+                fval = f0vals[elem][i]
+                if energy is not None:
+                    fval += f1vals[elem] - 1j*f2vals[elem]
+                for occu, fcoord in sites[elem]:
+                    fsum += fval*occu*np.exp(1j*TAU*(fcoord*hkl).sum())
+            f2[i] = (fsum*fsum.conjugate()).real
+        return f2
+
+
+    def get_pmg_struct(self):
+        if self.pmg_cstruct is not None and self.pmg_pstruct is not None:
+            return
+
+        try:
+            pmcif = CifParser(StringIO(self.ciftext), **PMG_CIF_OPTS)
+            self.pmg_cstruct = pmcif.get_structures()[0]
+            self.pmg_pstruct = SpacegroupAnalyzer(self.pmg_cstruct
+                                                  ).get_conventional_standard_structure()
+        except:
+            print(f"pymatgen could not parse CIF structure for CIF {self.ams_id}")
+
+
+    def get_unitcell(self):
+        "unitcell as dict, from PMG structure"
+        self.get_pmg_struct()
+        pstruct = self.pmg_pstruct
+        if pstruct is None:
+            print(f"pymatgen could not parse CIF structure for CIF {self.ams_id}")
+            return
+        pdict = pstruct.as_dict()
+        unitcell = {}
+        for a in ('a', 'b', 'c', 'alpha', 'beta', 'gamma', 'volume'):
+            unitcell[a] = pdict['lattice'][a]
+        return unitcell
+
+    def get_sites(self):
+        "dictionary of sites, from PMG structure"
+        self.get_pmg_struct()
+        pstruct = self.pmg_pstruct
+        if pstruct is None:
+            print(f"pymatgen could not parse CIF structure for CIF {self.ams_id}")
+            return
+
+        sites = {}
+        for site in pstruct.sites:
+            sdat = site.as_dict()
+            fcoords = sdat['abc']
+
+            for spec in sdat['species']:
+                elem = spec['element']
+                if elem == 'Nh': elem = 'N'
+                if elem == 'Og':
+                    elem = 'O'
+                if elem in ('Hs', 'D'):
+                    elem = 'H'
+                if elem.startswith('Dh') or elem.startswith('Dd') or elem.startswith('Dw'):
+                    elem = 'H'
+                if elem == 'Fl':
+                    elem = 'F'
+                occu = spec['occu']
+                if elem not in sites:
+                    sites[elem] = [(occu, fcoords)]
+                else:
+                    sites[elem].append([occu, fcoords])
+        return sites
+
 
 
     def get_feffinp(self, absorber, edge=None, cluster_size=8.0, absorber_site=1,
@@ -348,11 +637,9 @@ class CifStructure():
             else:
                 name = f'{absorber:s}_{edge:s}_{min_name:s}_CIF{self.ams_id:06d}'
 
-            bfolder = os.path.join(user_larchdir, 'feff6', name)
-            if not os.path.exists(bfolder):
-                os.makedirs(bfolder)
-
-            filename = os.path.join(bfolder, 'feff.inp')
+            ffolder = os.path.join(user_larchdir, 'feff', name)
+            mkdir(ffolder)
+            filename = os.path.join(ffolder, 'feff.inp')
         with open(filename, 'w', encoding=sys.getdefaultencoding()) as fh:
             fh.write(feff6text)
         return filename
@@ -376,7 +663,7 @@ class AMCSD():
             raise ValueError("'%s' is not a valid AMCSD Database!" % dbname)
 
         self.connect(dbname, read_only=read_only)
-
+        atexit.register(self.finalize_amcsd)
         ciftab = self.tables['cif']
         for colname in CIF_TEXTCOLUMNS:
             if colname not in ciftab.columns and not read_only:
@@ -387,6 +674,10 @@ class AMCSD():
                 self.insert('version', tag=f'with {colname}', date=isotime(),
                             notes=f'added {colname} column to cif table')
 
+    def finalize_amcsd(self):
+        conn = getattr(self, 'conn', None)
+        if conn is not None:
+            conn.close()
 
     def connect(self, dbname, read_only=False):
         self.dbname = dbname
@@ -609,7 +900,7 @@ class AMCSD():
 
     def add_ciffile(self, filename, cif_id=None, url='', debug=False):
 
-        if not HAS_CIFPARSER:
+        if CifParser is None:
             raise ValueError("CifParser from pymatgen not available. Try 'pip install pymatgen'.")
         try:
             dat, formula, symm_xyz = parse_cif_file(filename)
@@ -787,7 +1078,7 @@ class AMCSD():
 
         out = CifStructure(ams_id=cif_id, publication=pub,
                            mineral=mineral, spacegroup=sgroup,
-                           hm_symbol=hm_symbol)
+                           hm_symbol=hm_symbol, ams_db=self)
 
         for attr in ('formula_title', 'compound', 'formula', 'pub_title'):
             setattr(out, attr, getattr(cif, attr, '<missing>'))
@@ -835,15 +1126,15 @@ class AMCSD():
                 except:
                     print(f"could not parse CIF entry for {cif_id} '{attr}': {val} ")
 
-        out.qval = None
-        if cif.qdat is not None:
-            out.qval = np.unpackbits(np.array([int(b) for b in b64decode(cif.qdat)],
-                                              dtype='uint8'))
+        # we're now ignoring per-cif qvalues
+        # out.qval = None
+        # if cif.qdat is not None:
+        #     out.qval = np.unpackbits(np.array([int(b) for b in b64decode(cif.qdat)],
+        #                                       dtype='uint8'))
+
         out.hkls = None
         if hasattr(cif, 'hkls'):
-           if cif.hkls is not None:
-               tmp = np.array([int(i) for i in b64decode(cif.hkls)])
-               out.hkls = tmp.reshape(len(tmp)//3, 3)
+            out.hkls = cif.hkls
 
         return out
 
@@ -972,7 +1263,7 @@ class AMCSD():
                 matches = new_matches
 
             if strict_contains:
-                excludes_elements = elem_symbol[:]
+                excludes_elements = ATOM_SYMS[:]
                 for c in contains_elements:
                     if c in excludes_elements:
                         excludes_elements.remove(c)
@@ -1006,10 +1297,11 @@ class AMCSD():
             matches = matches[:max_matches]
         return [self.get_cif(cid) for cid in matches]
 
-    def set_hkls(self, cifid, hkls):
-        hkldat = b64encode(bytes(hkls[:].flatten().tolist()))
+    def set_hkls(self, cifid, hkls, degens):
         ctab = self.tables['cif']
-        self.update(ctab, whereclause=(ctab.c.id == cifid), hkls=hkldat)
+        packed_hkls = pack_hkl_degen(hkls, degens)
+        self.update(ctab, whereclause=(ctab.c.id == cifid), hkls=packed_hkls)
+        return packed_hkls
 
 def get_amcsd(download_full=True, timeout=30):
     """return instance of the AMCSD CIF Database
